import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Private certificate authority.
 */
export declare function getCertificateAuthority(args: GetCertificateAuthorityArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateAuthorityResult>;
export interface GetCertificateAuthorityArgs {
    /**
     * The Amazon Resource Name (ARN) of the certificate authority.
     */
    arn: string;
}
export interface GetCertificateAuthorityResult {
    /**
     * The Amazon Resource Name (ARN) of the certificate authority.
     */
    readonly arn?: string;
    /**
     * The base64 PEM-encoded certificate signing request (CSR) for your certificate authority certificate.
     */
    readonly certificateSigningRequest?: string;
    /**
     * Key-value pairs that will be attached to the new private CA. You can associate up to 50 tags with a private CA. For information using tags with IAM to manage permissions, see [Controlling Access Using IAM Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html) .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Private certificate authority.
 */
export declare function getCertificateAuthorityOutput(args: GetCertificateAuthorityOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCertificateAuthorityResult>;
export interface GetCertificateAuthorityOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the certificate authority.
     */
    arn: pulumi.Input<string>;
}
