import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::RequestValidator`` resource sets up basic validation rules for incoming requests to your API. For more information, see [Enable Basic Request Validation for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-method-request-validation.html) in the *API Gateway Developer Guide*.
 */
export declare function getRequestValidator(args: GetRequestValidatorArgs, opts?: pulumi.InvokeOptions): Promise<GetRequestValidatorResult>;
export interface GetRequestValidatorArgs {
    /**
     * The ID for the request validator. For example: `abc123` .
     */
    requestValidatorId: string;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: string;
}
export interface GetRequestValidatorResult {
    /**
     * The ID for the request validator. For example: `abc123` .
     */
    readonly requestValidatorId?: string;
    /**
     * A Boolean flag to indicate whether to validate a request body according to the configured Model schema.
     */
    readonly validateRequestBody?: boolean;
    /**
     * A Boolean flag to indicate whether to validate request parameters ( `true` ) or not ( `false` ).
     */
    readonly validateRequestParameters?: boolean;
}
/**
 * The ``AWS::ApiGateway::RequestValidator`` resource sets up basic validation rules for incoming requests to your API. For more information, see [Enable Basic Request Validation for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-method-request-validation.html) in the *API Gateway Developer Guide*.
 */
export declare function getRequestValidatorOutput(args: GetRequestValidatorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRequestValidatorResult>;
export interface GetRequestValidatorOutputArgs {
    /**
     * The ID for the request validator. For example: `abc123` .
     */
    requestValidatorId: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
}
