import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Schema for AWS::ApiGatewayV2::RoutingRule
 */
export declare function getRoutingRule(args: GetRoutingRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetRoutingRuleResult>;
export interface GetRoutingRuleArgs {
    /**
     * Amazon Resource Name (ARN) of the resource.
     */
    routingRuleArn: string;
}
export interface GetRoutingRuleResult {
    /**
     * The resulting action based on matching a routing rules condition. Only InvokeApi is supported.
     */
    readonly actions?: outputs.apigatewayv2.RoutingRuleAction[];
    /**
     * The conditions of the routing rule.
     */
    readonly conditions?: outputs.apigatewayv2.RoutingRuleCondition[];
    /**
     * The order in which API Gateway evaluates a rule. Priority is evaluated from the lowest value to the highest value. Rules can't have the same priority. Priority values 1-1,000,000 are supported.
     */
    readonly priority?: number;
    /**
     * Amazon Resource Name (ARN) of the resource.
     */
    readonly routingRuleArn?: string;
    /**
     * RoutingRule Id generated by service
     */
    readonly routingRuleId?: string;
}
/**
 * Schema for AWS::ApiGatewayV2::RoutingRule
 */
export declare function getRoutingRuleOutput(args: GetRoutingRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRoutingRuleResult>;
export interface GetRoutingRuleOutputArgs {
    /**
     * Amazon Resource Name (ARN) of the resource.
     */
    routingRuleArn: pulumi.Input<string>;
}
