import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::Model`` resource updates data model for a WebSocket API. For more information, see [Model Selection Expressions](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-model-selection-expressions) in the *API Gateway Developer Guide*.
 */
export declare class Model extends pulumi.CustomResource {
    /**
     * Get an existing Model resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Model;
    /**
     * Returns true if the given object is an instance of Model.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Model;
    /**
     * The API identifier.
     */
    readonly apiId: pulumi.Output<string>;
    /**
     * The content-type for the model, for example, "application/json".
     */
    readonly contentType: pulumi.Output<string | undefined>;
    /**
     * The description of the model.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The model ID.
     */
    readonly modelId: pulumi.Output<string>;
    /**
     * The name of the model.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The schema for the model. For application/json models, this should be JSON schema draft 4 model.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::Model` for more information about the expected schema for this property.
     */
    readonly schema: pulumi.Output<any>;
    /**
     * Create a Model resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Model resource.
 */
export interface ModelArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The content-type for the model, for example, "application/json".
     */
    contentType?: pulumi.Input<string>;
    /**
     * The description of the model.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the model.
     */
    name?: pulumi.Input<string>;
    /**
     * The schema for the model. For application/json models, this should be JSON schema draft 4 model.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::Model` for more information about the expected schema for this property.
     */
    schema: any;
}
