import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppSync::GraphQLApi
 */
export declare function getGraphQlApi(args: GetGraphQlApiArgs, opts?: pulumi.InvokeOptions): Promise<GetGraphQlApiResult>;
export interface GetGraphQlApiArgs {
    /**
     * Unique AWS AppSync GraphQL API identifier.
     */
    apiId: string;
}
export interface GetGraphQlApiResult {
    /**
     * A list of additional authentication providers for the GraphqlApi API.
     */
    readonly additionalAuthenticationProviders?: outputs.appsync.GraphQlApiAdditionalAuthenticationProvider[];
    /**
     * Unique AWS AppSync GraphQL API identifier.
     */
    readonly apiId?: string;
    /**
     * The value that indicates whether the GraphQL API is a standard API (GRAPHQL) or merged API (MERGED).
     */
    readonly apiType?: string;
    /**
     * The Amazon Resource Name (ARN) of the API key
     */
    readonly arn?: string;
    /**
     * Security configuration for your GraphQL API
     */
    readonly authenticationType?: string;
    /**
     * Enables and controls the enhanced metrics feature. Enhanced metrics emit granular data on API usage and performance such as AppSync request and error counts, latency, and cache hits/misses. All enhanced metric data is sent to your CloudWatch account, and you can configure the types of data that will be sent.
     */
    readonly enhancedMetricsConfig?: outputs.appsync.GraphQlApiEnhancedMetricsConfig;
    /**
     * A map containing the list of resources with their properties and environment variables.
     */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
     * The fully qualified domain name (FQDN) of the endpoint URL of your GraphQL API.
     */
    readonly graphQlDns?: string;
    /**
     * The GraphQL endpoint ARN.
     */
    readonly graphQlEndpointArn?: string;
    /**
     * The Endpoint URL of your GraphQL API.
     */
    readonly graphQlUrl?: string;
    /**
     * Sets the value of the GraphQL API to enable (ENABLED) or disable (DISABLED) introspection. If no value is provided, the introspection configuration will be set to ENABLED by default. This field will produce an error if the operation attempts to use the introspection feature while this field is disabled.
     */
    readonly introspectionConfig?: string;
    /**
     * A LambdaAuthorizerConfig holds configuration on how to authorize AWS AppSync API access when using the AWS_LAMBDA authorizer mode. Be aware that an AWS AppSync API may have only one Lambda authorizer configured at a time.
     */
    readonly lambdaAuthorizerConfig?: outputs.appsync.GraphQlApiLambdaAuthorizerConfig;
    /**
     * The Amazon CloudWatch Logs configuration.
     */
    readonly logConfig?: outputs.appsync.GraphQlApiLogConfig;
    /**
     * The AWS Identity and Access Management service role ARN for a merged API.
     */
    readonly mergedApiExecutionRoleArn?: string;
    /**
     * The API name
     */
    readonly name?: string;
    /**
     * The OpenID Connect configuration.
     */
    readonly openIdConnectConfig?: outputs.appsync.GraphQlApiOpenIdConnectConfig;
    /**
     * The owner contact information for an API resource.
     */
    readonly ownerContact?: string;
    /**
     * The maximum depth a query can have in a single request. Depth refers to the amount of nested levels allowed in the body of query.
     */
    readonly queryDepthLimit?: number;
    /**
     * The fully qualified domain name (FQDN) of the real-time endpoint URL of your GraphQL API.
     */
    readonly realtimeDns?: string;
    /**
     * The GraphQL API real-time endpoint URL.
     */
    readonly realtimeUrl?: string;
    /**
     * The maximum number of resolvers that can be invoked in a single request.
     */
    readonly resolverCountLimit?: number;
    /**
     * An arbitrary set of tags (key-value pairs) for this GraphQL API.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Optional authorization configuration for using Amazon Cognito user pools with your GraphQL endpoint.
     */
    readonly userPoolConfig?: outputs.appsync.GraphQlApiUserPoolConfig;
    /**
     * Sets the scope of the GraphQL API to public (GLOBAL) or private (PRIVATE). By default, the scope is set to Global if no value is provided.
     */
    readonly visibility?: string;
    /**
     * A flag indicating whether to use AWS X-Ray tracing for this GraphqlApi.
     */
    readonly xrayEnabled?: boolean;
}
/**
 * Resource Type definition for AWS::AppSync::GraphQLApi
 */
export declare function getGraphQlApiOutput(args: GetGraphQlApiOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGraphQlApiResult>;
export interface GetGraphQlApiOutputArgs {
    /**
     * Unique AWS AppSync GraphQL API identifier.
     */
    apiId: pulumi.Input<string>;
}
