import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::ARCZonalShift::ZonalAutoshiftConfiguration Resource Type
 */
export declare class ZonalAutoshiftConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing ZonalAutoshiftConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ZonalAutoshiftConfiguration;
    /**
     * Returns true if the given object is an instance of ZonalAutoshiftConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ZonalAutoshiftConfiguration;
    /**
     * A practice run configuration for a resource includes the Amazon CloudWatch alarms that you've specified for a practice run, as well as any blocked dates or blocked windows for the practice run. When a resource has a practice run configuration, ARC shifts traffic for the resource weekly for practice runs.
     *
     * Practice runs are required for zonal autoshift. The zonal shifts that ARC starts for practice runs help you to ensure that shifting away traffic from an Availability Zone during an autoshift is safe for your application.
     *
     * You can update or delete a practice run configuration. Before you delete a practice run configuration, you must disable zonal autoshift for the resource. A practice run configuration is required when zonal autoshift is enabled.
     */
    readonly practiceRunConfiguration: pulumi.Output<outputs.arczonalshift.ZonalAutoshiftConfigurationPracticeRunConfiguration | undefined>;
    /**
     * The identifier for the resource that AWS shifts traffic for. The identifier is the Amazon Resource Name (ARN) for the resource.
     *
     * At this time, supported resources are Network Load Balancers and Application Load Balancers.
     */
    readonly resourceIdentifier: pulumi.Output<string | undefined>;
    /**
     * When zonal autoshift is `ENABLED` , you authorize AWS to shift away resource traffic for an application from an Availability Zone during events, on your behalf, to help reduce time to recovery. Traffic is also shifted away for the required weekly practice runs.
     */
    readonly zonalAutoshiftStatus: pulumi.Output<enums.arczonalshift.ZonalAutoshiftConfigurationZonalAutoshiftStatus | undefined>;
    /**
     * Create a ZonalAutoshiftConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ZonalAutoshiftConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ZonalAutoshiftConfiguration resource.
 */
export interface ZonalAutoshiftConfigurationArgs {
    /**
     * A practice run configuration for a resource includes the Amazon CloudWatch alarms that you've specified for a practice run, as well as any blocked dates or blocked windows for the practice run. When a resource has a practice run configuration, ARC shifts traffic for the resource weekly for practice runs.
     *
     * Practice runs are required for zonal autoshift. The zonal shifts that ARC starts for practice runs help you to ensure that shifting away traffic from an Availability Zone during an autoshift is safe for your application.
     *
     * You can update or delete a practice run configuration. Before you delete a practice run configuration, you must disable zonal autoshift for the resource. A practice run configuration is required when zonal autoshift is enabled.
     */
    practiceRunConfiguration?: pulumi.Input<inputs.arczonalshift.ZonalAutoshiftConfigurationPracticeRunConfigurationArgs>;
    /**
     * The identifier for the resource that AWS shifts traffic for. The identifier is the Amazon Resource Name (ARN) for the resource.
     *
     * At this time, supported resources are Network Load Balancers and Application Load Balancers.
     */
    resourceIdentifier?: pulumi.Input<string>;
    /**
     * When zonal autoshift is `ENABLED` , you authorize AWS to shift away resource traffic for an application from an Availability Zone during events, on your behalf, to help reduce time to recovery. Traffic is also shifted away for the required weekly practice runs.
     */
    zonalAutoshiftStatus?: pulumi.Input<enums.arczonalshift.ZonalAutoshiftConfigurationZonalAutoshiftStatus>;
}
