import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Backup::LogicallyAirGappedBackupVault
 */
export declare function getLogicallyAirGappedBackupVault(args: GetLogicallyAirGappedBackupVaultArgs, opts?: pulumi.InvokeOptions): Promise<GetLogicallyAirGappedBackupVaultResult>;
export interface GetLogicallyAirGappedBackupVaultArgs {
    /**
     * The name of a logical container where backups are stored. Logically air-gapped backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.
     */
    backupVaultName: string;
}
export interface GetLogicallyAirGappedBackupVaultResult {
    /**
     * The backup vault access policy document in JSON format.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Backup::LogicallyAirGappedBackupVault` for more information about the expected schema for this property.
     */
    readonly accessPolicy?: any;
    /**
     * The ARN of the backup vault.
     */
    readonly backupVaultArn?: string;
    /**
     * The tags to assign to the vault.
     */
    readonly backupVaultTags?: {
        [key: string]: string;
    };
    /**
     * The ARN of the server-side encryption key.
     */
    readonly encryptionKeyArn?: string;
    /**
     * Returns event notifications for the specified backup vault.
     */
    readonly notifications?: outputs.backup.LogicallyAirGappedBackupVaultNotificationObjectType;
    /**
     * The vault state. The possible values are `CREATING` , `AVAILABLE` , and `FAILED` .
     */
    readonly vaultState?: string;
    /**
     * The vault type. The possible values are `BACKUP_VAULT` and `LOGICALLY_AIR_GAPPED_BACKUP_VAULT` .
     */
    readonly vaultType?: string;
}
/**
 * Resource Type definition for AWS::Backup::LogicallyAirGappedBackupVault
 */
export declare function getLogicallyAirGappedBackupVaultOutput(args: GetLogicallyAirGappedBackupVaultOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLogicallyAirGappedBackupVaultResult>;
export interface GetLogicallyAirGappedBackupVaultOutputArgs {
    /**
     * The name of a logical container where backups are stored. Logically air-gapped backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.
     */
    backupVaultName: pulumi.Input<string>;
}
