import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Backup::RestoreTestingSelection
 */
export declare function getRestoreTestingSelection(args: GetRestoreTestingSelectionArgs, opts?: pulumi.InvokeOptions): Promise<GetRestoreTestingSelectionResult>;
export interface GetRestoreTestingSelectionArgs {
    /**
     * Unique string that is the name of the restore testing plan.
     *
     * The name cannot be changed after creation. The name must consist of only alphanumeric characters and underscores. Maximum length is 50.
     */
    restoreTestingPlanName: string;
    /**
     * The unique name of the restore testing selection that belongs to the related restore testing plan.
     */
    restoreTestingSelectionName: string;
}
export interface GetRestoreTestingSelectionResult {
    /**
     * The Amazon Resource Name (ARN) of the IAM role that AWS Backup uses to create the target resource; for example: `arn:aws:iam::123456789012:role/S3Access` .
     */
    readonly iamRoleArn?: string;
    /**
     * You can include specific ARNs, such as `ProtectedResourceArns: ["arn:aws:...", "arn:aws:..."]` or you can include a wildcard: `ProtectedResourceArns: ["*"]` , but not both.
     */
    readonly protectedResourceArns?: string[];
    /**
     * In a resource testing selection, this parameter filters by specific conditions such as `StringEquals` or `StringNotEquals` .
     */
    readonly protectedResourceConditions?: outputs.backup.RestoreTestingSelectionProtectedResourceConditions;
    /**
     * You can override certain restore metadata keys by including the parameter `RestoreMetadataOverrides` in the body of `RestoreTestingSelection` . Key values are not case sensitive.
     *
     * See the complete list of [restore testing inferred metadata](https://docs.aws.amazon.com/aws-backup/latest/devguide/restore-testing-inferred-metadata.html) .
     */
    readonly restoreMetadataOverrides?: {
        [key: string]: string;
    };
    /**
     * This is amount of hours (1 to 168) available to run a validation script on the data. The data will be deleted upon the completion of the validation script or the end of the specified retention period, whichever comes first.
     */
    readonly validationWindowHours?: number;
}
/**
 * Resource Type definition for AWS::Backup::RestoreTestingSelection
 */
export declare function getRestoreTestingSelectionOutput(args: GetRestoreTestingSelectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRestoreTestingSelectionResult>;
export interface GetRestoreTestingSelectionOutputArgs {
    /**
     * Unique string that is the name of the restore testing plan.
     *
     * The name cannot be changed after creation. The name must consist of only alphanumeric characters and underscores. Maximum length is 50.
     */
    restoreTestingPlanName: pulumi.Input<string>;
    /**
     * The unique name of the restore testing selection that belongs to the related restore testing plan.
     */
    restoreTestingSelectionName: pulumi.Input<string>;
}
