import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::DataAutomationProject Resource Type
 */
export declare class DataAutomationProject extends pulumi.CustomResource {
    /**
     * Get an existing DataAutomationProject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataAutomationProject;
    /**
     * Returns true if the given object is an instance of DataAutomationProject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataAutomationProject;
    /**
     * Time Stamp
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * Blueprints to apply to objects processed by the project.
     */
    readonly customOutputConfiguration: pulumi.Output<outputs.bedrock.DataAutomationProjectCustomOutputConfiguration | undefined>;
    /**
     * KMS encryption context
     */
    readonly kmsEncryptionContext: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * KMS key identifier
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * Time Stamp
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * Additional settings for the project.
     */
    readonly overrideConfiguration: pulumi.Output<outputs.bedrock.DataAutomationProjectOverrideConfiguration | undefined>;
    /**
     * ARN of a DataAutomationProject
     */
    readonly projectArn: pulumi.Output<string>;
    /**
     * Description of the DataAutomationProject
     */
    readonly projectDescription: pulumi.Output<string | undefined>;
    /**
     * Name of the DataAutomationProject
     */
    readonly projectName: pulumi.Output<string>;
    /**
     * The project's stage.
     */
    readonly projectStage: pulumi.Output<enums.bedrock.DataAutomationProjectStage>;
    /**
     * The project's standard output configuration.
     */
    readonly standardOutputConfiguration: pulumi.Output<outputs.bedrock.DataAutomationProjectStandardOutputConfiguration | undefined>;
    /**
     * The project's status.
     */
    readonly status: pulumi.Output<enums.bedrock.DataAutomationProjectStatus>;
    /**
     * List of Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DataAutomationProject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DataAutomationProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataAutomationProject resource.
 */
export interface DataAutomationProjectArgs {
    /**
     * Blueprints to apply to objects processed by the project.
     */
    customOutputConfiguration?: pulumi.Input<inputs.bedrock.DataAutomationProjectCustomOutputConfigurationArgs>;
    /**
     * KMS encryption context
     */
    kmsEncryptionContext?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * KMS key identifier
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * Additional settings for the project.
     */
    overrideConfiguration?: pulumi.Input<inputs.bedrock.DataAutomationProjectOverrideConfigurationArgs>;
    /**
     * Description of the DataAutomationProject
     */
    projectDescription?: pulumi.Input<string>;
    /**
     * Name of the DataAutomationProject
     */
    projectName?: pulumi.Input<string>;
    /**
     * The project's standard output configuration.
     */
    standardOutputConfiguration?: pulumi.Input<inputs.bedrock.DataAutomationProjectStandardOutputConfigurationArgs>;
    /**
     * List of Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
