import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A billing view is a container of cost & usage metadata.
 */
export declare class BillingView extends pulumi.CustomResource {
    /**
     * Get an existing BillingView resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BillingView;
    /**
     * Returns true if the given object is an instance of BillingView.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BillingView;
    readonly arn: pulumi.Output<string>;
    readonly billingViewType: pulumi.Output<enums.billing.BillingViewType>;
    /**
     * The time when the billing view was created.
     */
    readonly createdAt: pulumi.Output<number>;
    readonly dataFilterExpression: pulumi.Output<outputs.billing.DataFilterExpressionProperties | undefined>;
    readonly description: pulumi.Output<string | undefined>;
    readonly name: pulumi.Output<string>;
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * An array of strings that define the billing view's source.
     */
    readonly sourceViews: pulumi.Output<string[]>;
    /**
     * An array of key-value pairs associated to the billing view being created.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The time when the billing view was last updated.
     */
    readonly updatedAt: pulumi.Output<number>;
    /**
     * Create a BillingView resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BillingViewArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BillingView resource.
 */
export interface BillingViewArgs {
    dataFilterExpression?: pulumi.Input<inputs.billing.DataFilterExpressionPropertiesArgs>;
    description?: pulumi.Input<string>;
    name?: pulumi.Input<string>;
    /**
     * An array of strings that define the billing view's source.
     */
    sourceViews: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An array of key-value pairs associated to the billing view being created.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
