import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Represents a table that can be queried within a collaboration
 */
export declare function getConfiguredTableAssociation(args: GetConfiguredTableAssociationArgs, opts?: pulumi.InvokeOptions): Promise<GetConfiguredTableAssociationResult>;
export interface GetConfiguredTableAssociationArgs {
    /**
     * Returns the unique identifier of the specified configured table association.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    configuredTableAssociationIdentifier: string;
    /**
     * The unique ID for the membership this configured table association belongs to.
     */
    membershipIdentifier: string;
}
export interface GetConfiguredTableAssociationResult {
    /**
     * Returns the Amazon Resource Name (ARN) of the specified configured table association.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:configuredtable/a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly arn?: string;
    /**
     * An analysis rule for a configured table association. This analysis rule specifies how data from the table can be used within its associated collaboration. In the console, the `ConfiguredTableAssociationAnalysisRule` is referred to as the *collaboration analysis rule* .
     */
    readonly configuredTableAssociationAnalysisRules?: outputs.cleanrooms.ConfiguredTableAssociationAnalysisRule[];
    /**
     * Returns the unique identifier of the specified configured table association.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly configuredTableAssociationIdentifier?: string;
    /**
     * A description of the configured table association.
     */
    readonly description?: string;
    /**
     * The service will assume this role to access catalog metadata and query the table.
     */
    readonly roleArn?: string;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents a table that can be queried within a collaboration
 */
export declare function getConfiguredTableAssociationOutput(args: GetConfiguredTableAssociationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfiguredTableAssociationResult>;
export interface GetConfiguredTableAssociationOutputArgs {
    /**
     * Returns the unique identifier of the specified configured table association.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    configuredTableAssociationIdentifier: pulumi.Input<string>;
    /**
     * The unique ID for the membership this configured table association belongs to.
     */
    membershipIdentifier: pulumi.Input<string>;
}
