import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An Amazon CloudFront VPC origin.
 */
export declare class VpcOrigin extends pulumi.CustomResource {
    /**
     * Get an existing VpcOrigin resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcOrigin;
    /**
     * Returns true if the given object is an instance of VpcOrigin.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcOrigin;
    /**
     * The VPC origin ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The VPC origin ID.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The VPC origin created time.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The VPC origin last modified time.
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * The VPC origin status.
     */
    readonly status: pulumi.Output<string>;
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The VPC origin endpoint configuration.
     */
    readonly vpcOriginEndpointConfig: pulumi.Output<outputs.cloudfront.VpcOriginEndpointConfig>;
    /**
     * Create a VpcOrigin resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcOriginArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcOrigin resource.
 */
export interface VpcOriginArgs {
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The VPC origin endpoint configuration.
     */
    vpcOriginEndpointConfig: pulumi.Input<inputs.cloudfront.VpcOriginEndpointConfigArgs>;
}
