import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * An Event Stream resource of Amazon Connect Customer Profiles
 */
export declare class EventStream extends pulumi.CustomResource {
    /**
     * Get an existing EventStream resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EventStream;
    /**
     * Returns true if the given object is an instance of EventStream.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EventStream;
    /**
     * The timestamp of when the export was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Details regarding the Kinesis stream.
     */
    readonly destinationDetails: pulumi.Output<outputs.customerprofiles.DestinationDetailsProperties>;
    /**
     * The unique name of the domain.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * A unique identifier for the event stream.
     */
    readonly eventStreamArn: pulumi.Output<string>;
    /**
     * The name of the event stream.
     */
    readonly eventStreamName: pulumi.Output<string>;
    /**
     * The operational state of destination stream for export.
     */
    readonly state: pulumi.Output<enums.customerprofiles.EventStreamState>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name.
     */
    readonly uri: pulumi.Output<string>;
    /**
     * Create a EventStream resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EventStreamArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EventStream resource.
 */
export interface EventStreamArgs {
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
    /**
     * The name of the event stream.
     */
    eventStreamName?: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name.
     */
    uri: pulumi.Input<string>;
}
