import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An ObjectType resource of Amazon Connect Customer Profiles
 */
export declare function getObjectType(args: GetObjectTypeArgs, opts?: pulumi.InvokeOptions): Promise<GetObjectTypeResult>;
export interface GetObjectTypeArgs {
    /**
     * The unique name of the domain.
     */
    domainName: string;
    /**
     * The name of the profile object type.
     */
    objectTypeName: string;
}
export interface GetObjectTypeResult {
    /**
     * Indicates whether a profile should be created when data is received.
     */
    readonly allowProfileCreation?: boolean;
    /**
     * The time of this integration got created.
     */
    readonly createdAt?: string;
    /**
     * Description of the profile object type.
     */
    readonly description?: string;
    /**
     * The default encryption key
     */
    readonly encryptionKey?: string;
    /**
     * The default number of days until the data within the domain expires.
     */
    readonly expirationDays?: number;
    /**
     * A list of the name and ObjectType field.
     */
    readonly fields?: outputs.customerprofiles.ObjectTypeFieldMap[];
    /**
     * A list of unique keys that can be used to map data to the profile.
     */
    readonly keys?: outputs.customerprofiles.ObjectTypeKeyMap[];
    /**
     * The time of this integration got last updated at.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The maximum available number of profile objects
     */
    readonly maxAvailableProfileObjectCount?: number;
    /**
     * The maximum number of profile objects for this object type
     */
    readonly maxProfileObjectCount?: number;
    /**
     * The format of your sourceLastUpdatedTimestamp that was previously set up.
     */
    readonly sourceLastUpdatedTimestampFormat?: string;
    /**
     * The tags (keys and values) associated with the integration.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A unique identifier for the object template.
     */
    readonly templateId?: string;
}
/**
 * An ObjectType resource of Amazon Connect Customer Profiles
 */
export declare function getObjectTypeOutput(args: GetObjectTypeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetObjectTypeResult>;
export interface GetObjectTypeOutputArgs {
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
    /**
     * The name of the profile object type.
     */
    objectTypeName: pulumi.Input<string>;
}
