import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataSync::LocationFSxLustre.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const locationFSxLustre = new aws_native.datasync.LocationFSxLustre("locationFSxLustre", {
 *     fsxFilesystemArn: "arn:aws:fsx:us-east-2:111222333444:file-system/fs-12345fsx",
 *     securityGroupArns: ["arn:aws:ec2:us-east-2:11122233344:security-group/sg-12345678901212345"],
 *     subdirectory: "/MySubdirectory",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const locationFSxLustre = new aws_native.datasync.LocationFSxLustre("locationFSxLustre", {
 *     fsxFilesystemArn: "arn:aws:fsx:us-east-2:111222333444:file-system/fs-12345fsx",
 *     securityGroupArns: ["arn:aws:ec2:us-east-2:11122233344:security-group/sg-12345678901212345"],
 *     subdirectory: "/MySubdirectory",
 * });
 *
 * ```
 */
export declare class LocationFSxLustre extends pulumi.CustomResource {
    /**
     * Get an existing LocationFSxLustre resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationFSxLustre;
    /**
     * Returns true if the given object is an instance of LocationFSxLustre.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationFSxLustre;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Lustre file system.
     */
    readonly fsxFilesystemArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon FSx for Lustre file system location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the FSx for Lustre location that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx for Lustre file system.
     */
    readonly securityGroupArns: pulumi.Output<string[]>;
    /**
     * A subdirectory in the location's path.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationFSxLustre resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationFSxLustreArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationFSxLustre resource.
 */
export interface LocationFSxLustreArgs {
    /**
     * The Amazon Resource Name (ARN) for the FSx for Lustre file system.
     */
    fsxFilesystemArn?: pulumi.Input<string>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx for Lustre file system.
     */
    securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A subdirectory in the location's path.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
