import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A user profile represents Amazon DataZone users. Amazon DataZone supports both IAM roles and SSO identities to interact with the Amazon DataZone Management Console and the data portal for different purposes. Domain administrators use IAM roles to perform the initial administrative domain-related work in the Amazon DataZone Management Console, including creating new Amazon DataZone domains, configuring metadata form types, and implementing policies. Data workers use their SSO corporate identities via Identity Center to log into the Amazon DataZone Data Portal and access projects where they have memberships.
 */
export declare class UserProfile extends pulumi.CustomResource {
    /**
     * Get an existing UserProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): UserProfile;
    /**
     * Returns true if the given object is an instance of UserProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserProfile;
    /**
     * The ID of the Amazon DataZone user profile.
     */
    readonly awsId: pulumi.Output<string>;
    readonly details: pulumi.Output<outputs.datazone.UserProfileDetails0Properties | outputs.datazone.UserProfileDetails1Properties>;
    /**
     * The identifier of the Amazon DataZone domain in which the user profile is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the Amazon DataZone domain in which the user profile would be created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The status of the user profile.
     */
    readonly status: pulumi.Output<enums.datazone.UserProfileStatus | undefined>;
    /**
     * The type of the user profile.
     */
    readonly type: pulumi.Output<enums.datazone.UserProfileType>;
    /**
     * The ID of the user.
     */
    readonly userIdentifier: pulumi.Output<string>;
    /**
     * The user type of the user for which the user profile is created.
     */
    readonly userType: pulumi.Output<enums.datazone.UserProfileUserType | undefined>;
    /**
     * Create a UserProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a UserProfile resource.
 */
export interface UserProfileArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the user profile would be created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The status of the user profile.
     */
    status?: pulumi.Input<enums.datazone.UserProfileStatus>;
    /**
     * The ID of the user.
     */
    userIdentifier: pulumi.Input<string>;
    /**
     * The user type of the user for which the user profile is created.
     */
    userType?: pulumi.Input<enums.datazone.UserProfileUserType>;
}
