import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::DocDBElastic::Cluster Amazon DocumentDB (with MongoDB compatibility) Elastic Scale resource describes a Cluster
 */
export declare function getCluster(args: GetClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterResult>;
export interface GetClusterArgs {
    clusterArn: string;
}
export interface GetClusterResult {
    /**
     * The number of days for which automatic snapshots are retained.
     */
    readonly backupRetentionPeriod?: number;
    readonly clusterArn?: string;
    /**
     * The URL used to connect to the elastic cluster.
     */
    readonly clusterEndpoint?: string;
    /**
     * The daily time range during which automated backups are created if automated backups are enabled, as determined by `backupRetentionPeriod` .
     */
    readonly preferredBackupWindow?: string;
    /**
     * The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
     *
     * *Format* : `ddd:hh24:mi-ddd:hh24:mi`
     *
     * *Default* : a 30-minute window selected at random from an 8-hour block of time for each AWS Region , occurring on a random day of the week.
     *
     * *Valid days* : Mon, Tue, Wed, Thu, Fri, Sat, Sun
     *
     * *Constraints* : Minimum 30-minute window.
     */
    readonly preferredMaintenanceWindow?: string;
    /**
     * The number of vCPUs assigned to each elastic cluster shard. Maximum is 64. Allowed values are 2, 4, 8, 16, 32, 64.
     */
    readonly shardCapacity?: number;
    /**
     * The number of shards assigned to the elastic cluster. Maximum is 32.
     */
    readonly shardCount?: number;
    /**
     * The number of replica instances applying to all shards in the cluster. A `shardInstanceCount` value of 1 means there is one writer instance, and any additional instances are replicas that can be used for reads and to improve availability.
     */
    readonly shardInstanceCount?: number;
    /**
     * The Amazon EC2 subnet IDs for the new elastic cluster.
     */
    readonly subnetIds?: string[];
    /**
     * The tags to be assigned to the new elastic cluster.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A list of EC2 VPC security groups to associate with the new elastic cluster.
     */
    readonly vpcSecurityGroupIds?: string[];
}
/**
 * The AWS::DocDBElastic::Cluster Amazon DocumentDB (with MongoDB compatibility) Elastic Scale resource describes a Cluster
 */
export declare function getClusterOutput(args: GetClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetClusterResult>;
export interface GetClusterOutputArgs {
    clusterArn: pulumi.Input<string>;
}
