import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::DSQL::Cluster
 */
export declare class Cluster extends pulumi.CustomResource {
    /**
     * Get an existing Cluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Cluster;
    /**
     * Returns true if the given object is an instance of Cluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Cluster;
    /**
     * The time of when the cluster was created in ISO-8601 format.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * Whether deletion protection is enabled in this cluster.
     */
    readonly deletionProtectionEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The encryption configuration details for the cluster.
     */
    readonly encryptionDetails: pulumi.Output<outputs.dsql.EncryptionDetailsProperties>;
    /**
     * The ID of the created cluster.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * The KMS key that encrypts data on the cluster.
     */
    readonly kmsEncryptionKey: pulumi.Output<string | undefined>;
    /**
     * The Multi-region properties associated to this cluster.
     */
    readonly multiRegionProperties: pulumi.Output<outputs.dsql.MultiRegionPropertiesProperties | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the cluster.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The status of the cluster.
     */
    readonly status: pulumi.Output<string>;
    /**
     * A map of key and value pairs this cluster is tagged with.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The VPC endpoint service name.
     */
    readonly vpcEndpointServiceName: pulumi.Output<string>;
    /**
     * Create a Cluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Cluster resource.
 */
export interface ClusterArgs {
    /**
     * Whether deletion protection is enabled in this cluster.
     */
    deletionProtectionEnabled?: pulumi.Input<boolean>;
    /**
     * The KMS key that encrypts data on the cluster.
     */
    kmsEncryptionKey?: pulumi.Input<string>;
    /**
     * The Multi-region properties associated to this cluster.
     */
    multiRegionProperties?: pulumi.Input<inputs.dsql.MultiRegionPropertiesPropertiesArgs>;
    /**
     * A map of key and value pairs this cluster is tagged with.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
