import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EC2::InstanceConnectEndpoint
 */
export declare class InstanceConnectEndpoint extends pulumi.CustomResource {
    /**
     * Get an existing InstanceConnectEndpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InstanceConnectEndpoint;
    /**
     * Returns true if the given object is an instance of InstanceConnectEndpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InstanceConnectEndpoint;
    /**
     * The id of the instance connect endpoint
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The client token of the instance connect endpoint.
     */
    readonly clientToken: pulumi.Output<string | undefined>;
    /**
     * If true, the address of the instance connect endpoint client is preserved when connecting to the end resource
     */
    readonly preserveClientIp: pulumi.Output<boolean | undefined>;
    /**
     * The security group IDs of the instance connect endpoint.
     */
    readonly securityGroupIds: pulumi.Output<string[] | undefined>;
    /**
     * The subnet id of the instance connect endpoint
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * The tags of the instance connect endpoint.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a InstanceConnectEndpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InstanceConnectEndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InstanceConnectEndpoint resource.
 */
export interface InstanceConnectEndpointArgs {
    /**
     * The client token of the instance connect endpoint.
     */
    clientToken?: pulumi.Input<string>;
    /**
     * If true, the address of the instance connect endpoint client is preserved when connecting to the end resource
     */
    preserveClientIp?: pulumi.Input<boolean>;
    /**
     * The security group IDs of the instance connect endpoint.
     */
    securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The subnet id of the instance connect endpoint
     */
    subnetId: pulumi.Input<string>;
    /**
     * The tags of the instance connect endpoint.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
