import * as pulumi from "@pulumi/pulumi";
/**
 * Associates a subnet with a route table. The subnet and route table must be in the same VPC. This association causes traffic originating from the subnet to be routed according to the routes in the route table. A route table can be associated with multiple subnets. To create a route table, see [AWS::EC2::RouteTable](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-routetable.html).
 */
export declare class SubnetRouteTableAssociation extends pulumi.CustomResource {
    /**
     * Get an existing SubnetRouteTableAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SubnetRouteTableAssociation;
    /**
     * Returns true if the given object is an instance of SubnetRouteTableAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubnetRouteTableAssociation;
    /**
     * The ID of the subnet route table association.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The ID of the route table.
     *  The physical ID changes when the route table ID is changed.
     */
    readonly routeTableId: pulumi.Output<string>;
    /**
     * The ID of the subnet.
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * Create a SubnetRouteTableAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubnetRouteTableAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SubnetRouteTableAssociation resource.
 */
export interface SubnetRouteTableAssociationArgs {
    /**
     * The ID of the route table.
     *  The physical ID changes when the route table ID is changed.
     */
    routeTableId: pulumi.Input<string>;
    /**
     * The ID of the subnet.
     */
    subnetId: pulumi.Input<string>;
}
