import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The description of the Traffic Mirror target.
 */
export declare class TrafficMirrorTarget extends pulumi.CustomResource {
    /**
     * Get an existing TrafficMirrorTarget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrafficMirrorTarget;
    /**
     * Returns true if the given object is an instance of TrafficMirrorTarget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficMirrorTarget;
    readonly awsId: pulumi.Output<string>;
    /**
     * The description of the Traffic Mirror target.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the Gateway Load Balancer endpoint.
     */
    readonly gatewayLoadBalancerEndpointId: pulumi.Output<string | undefined>;
    /**
     * The network interface ID that is associated with the target.
     */
    readonly networkInterfaceId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.
     */
    readonly networkLoadBalancerArn: pulumi.Output<string | undefined>;
    /**
     *  The tags to assign to the Traffic Mirror target.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a TrafficMirrorTarget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TrafficMirrorTargetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrafficMirrorTarget resource.
 */
export interface TrafficMirrorTargetArgs {
    /**
     * The description of the Traffic Mirror target.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the Gateway Load Balancer endpoint.
     */
    gatewayLoadBalancerEndpointId?: pulumi.Input<string>;
    /**
     * The network interface ID that is associated with the target.
     */
    networkInterfaceId?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.
     */
    networkLoadBalancerArn?: pulumi.Input<string>;
    /**
     *  The tags to assign to the Traffic Mirror target.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
