import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const finSpaceEnvironment = new aws_native.finspace.Environment("finSpaceEnvironment", {
 *     name: "MyEnvironment",
 *     kmsKeyId: "arn:aws:kms:us-east-1:123456789012:key/44efed01-30d0-4b39-80e7-165d5ed34524",
 *     federationMode: aws_native.finspace.EnvironmentFederationMode.Local,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const finSpaceEnvironment = new aws_native.finspace.Environment("finSpaceEnvironment", {
 *     name: "MyEnvironment",
 *     kmsKeyId: "arn:aws:kms:us-east-1:123456789012:key/44efed01-30d0-4b39-80e7-165d5ed34524",
 *     federationMode: aws_native.finspace.EnvironmentFederationMode.Local,
 * });
 *
 * ```
 */
export declare class Environment extends pulumi.CustomResource {
    /**
     * Get an existing Environment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Environment;
    /**
     * Returns true if the given object is an instance of Environment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Environment;
    /**
     * AWS account ID associated with the Environment
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * ARNs of FinSpace Data Bundles to install
     */
    readonly dataBundles: pulumi.Output<string[] | undefined>;
    /**
     * ID for FinSpace created account used to store Environment artifacts
     */
    readonly dedicatedServiceAccountId: pulumi.Output<string>;
    /**
     * Description of the Environment
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * ARN of the Environment
     */
    readonly environmentArn: pulumi.Output<string>;
    /**
     * Unique identifier for representing FinSpace Environment
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * URL used to login to the Environment
     */
    readonly environmentUrl: pulumi.Output<string>;
    /**
     * Federation mode used with the Environment
     */
    readonly federationMode: pulumi.Output<enums.finspace.EnvironmentFederationMode | undefined>;
    /**
     * Configuration information when authentication mode is FEDERATED.
     */
    readonly federationParameters: pulumi.Output<outputs.finspace.EnvironmentFederationParameters | undefined>;
    /**
     * KMS key used to encrypt customer data within FinSpace Environment infrastructure
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * Name of the Environment
     */
    readonly name: pulumi.Output<string>;
    /**
     * SageMaker Studio Domain URL associated with the Environment
     */
    readonly sageMakerStudioDomainUrl: pulumi.Output<string>;
    /**
     * State of the Environment
     */
    readonly status: pulumi.Output<enums.finspace.EnvironmentStatus>;
    /**
     * Configuration information for the superuser.
     */
    readonly superuserParameters: pulumi.Output<outputs.finspace.EnvironmentSuperuserParameters | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a Environment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EnvironmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Environment resource.
 */
export interface EnvironmentArgs {
    /**
     * ARNs of FinSpace Data Bundles to install
     */
    dataBundles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Description of the Environment
     */
    description?: pulumi.Input<string>;
    /**
     * Federation mode used with the Environment
     */
    federationMode?: pulumi.Input<enums.finspace.EnvironmentFederationMode>;
    /**
     * Configuration information when authentication mode is FEDERATED.
     */
    federationParameters?: pulumi.Input<inputs.finspace.EnvironmentFederationParametersArgs>;
    /**
     * KMS key used to encrypt customer data within FinSpace Environment infrastructure
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * Name of the Environment
     */
    name?: pulumi.Input<string>;
    /**
     * Configuration information for the superuser.
     */
    superuserParameters?: pulumi.Input<inputs.finspace.EnvironmentSuperuserParametersArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
