import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource type definition for AWS::FSx::S3AccessPointAttachment
 */
export declare class S3AccessPointAttachment extends pulumi.CustomResource {
    /**
     * Get an existing S3AccessPointAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): S3AccessPointAttachment;
    /**
     * Returns true if the given object is an instance of S3AccessPointAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is S3AccessPointAttachment;
    /**
     * The Name of the S3AccessPointAttachment
     */
    readonly name: pulumi.Output<string>;
    /**
     * The OpenZFSConfiguration of the S3 access point attachment.
     */
    readonly openZfsConfiguration: pulumi.Output<outputs.fsx.S3AccessPointAttachmentS3AccessPointOpenZfsConfiguration>;
    /**
     * The S3 access point configuration of the S3 access point attachment.
     */
    readonly s3AccessPoint: pulumi.Output<outputs.fsx.S3AccessPointAttachmentS3AccessPoint | undefined>;
    /**
     * The type of Amazon FSx volume that the S3 access point is attached to.
     */
    readonly type: pulumi.Output<enums.fsx.S3AccessPointAttachmentType>;
    /**
     * Create a S3AccessPointAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: S3AccessPointAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a S3AccessPointAttachment resource.
 */
export interface S3AccessPointAttachmentArgs {
    /**
     * The Name of the S3AccessPointAttachment
     */
    name?: pulumi.Input<string>;
    /**
     * The OpenZFSConfiguration of the S3 access point attachment.
     */
    openZfsConfiguration: pulumi.Input<inputs.fsx.S3AccessPointAttachmentS3AccessPointOpenZfsConfigurationArgs>;
    /**
     * The S3 access point configuration of the S3 access point attachment.
     */
    s3AccessPoint?: pulumi.Input<inputs.fsx.S3AccessPointAttachmentS3AccessPointArgs>;
    /**
     * The type of Amazon FSx volume that the S3 access point is attached to.
     */
    type: pulumi.Input<enums.fsx.S3AccessPointAttachmentType>;
}
