import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::GuardDuty::Member
 */
export declare class Member extends pulumi.CustomResource {
    /**
     * Get an existing Member resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Member;
    /**
     * Returns true if the given object is an instance of Member.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Member;
    /**
     * The ID of the detector associated with the GuardDuty service to add the member to.
     */
    readonly detectorId: pulumi.Output<string | undefined>;
    /**
     * Specifies whether or not to disable email notification for the member account that you invite.
     */
    readonly disableEmailNotification: pulumi.Output<boolean | undefined>;
    /**
     * The email address associated with the member account.
     */
    readonly email: pulumi.Output<string>;
    /**
     * The AWS account ID of the account to designate as a member.
     */
    readonly memberId: pulumi.Output<string | undefined>;
    /**
     * The invitation message that you want to send to the accounts that you're inviting to GuardDuty as members.
     */
    readonly message: pulumi.Output<string | undefined>;
    /**
     * You can use the `Status` property to update the status of the relationship between the member account and its administrator account. Valid values are `Created` and `Invited` when using an `AWS::GuardDuty::Member` resource. If the value for this property is not provided or set to `Created` , a member account is created but not invited. If the value of this property is set to `Invited` , a member account is created and invited.
     */
    readonly status: pulumi.Output<string | undefined>;
    /**
     * Create a Member resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MemberArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Member resource.
 */
export interface MemberArgs {
    /**
     * The ID of the detector associated with the GuardDuty service to add the member to.
     */
    detectorId?: pulumi.Input<string>;
    /**
     * Specifies whether or not to disable email notification for the member account that you invite.
     */
    disableEmailNotification?: pulumi.Input<boolean>;
    /**
     * The email address associated with the member account.
     */
    email: pulumi.Input<string>;
    /**
     * The AWS account ID of the account to designate as a member.
     */
    memberId?: pulumi.Input<string>;
    /**
     * The invitation message that you want to send to the accounts that you're inviting to GuardDuty as members.
     */
    message?: pulumi.Input<string>;
    /**
     * You can use the `Status` property to update the status of the relationship between the member account and its administrator account. Valid values are `Created` and `Invited` when using an `AWS::GuardDuty::Member` resource. If the value for this property is not provided or set to `Created` , a member account is created but not invited. If the value of this property is set to `Invited` , a member account is created and invited.
     */
    status?: pulumi.Input<string>;
}
