import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTSiteWise::Asset
 */
export declare class Asset extends pulumi.CustomResource {
    /**
     * Get an existing Asset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Asset;
    /**
     * Returns true if the given object is an instance of Asset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Asset;
    /**
     * The ARN of the asset
     */
    readonly assetArn: pulumi.Output<string>;
    /**
     * A description for the asset
     */
    readonly assetDescription: pulumi.Output<string | undefined>;
    /**
     * The External ID of the asset
     */
    readonly assetExternalId: pulumi.Output<string | undefined>;
    /**
     * A list of asset hierarchies that each contain a `hierarchyId` . A hierarchy specifies allowed parent/child asset relationships.
     */
    readonly assetHierarchies: pulumi.Output<outputs.iotsitewise.AssetHierarchy[] | undefined>;
    /**
     * The ID of the asset
     */
    readonly assetId: pulumi.Output<string>;
    /**
     * The ID of the asset model from which to create the asset.
     */
    readonly assetModelId: pulumi.Output<string>;
    /**
     * A unique, friendly name for the asset.
     */
    readonly assetName: pulumi.Output<string>;
    /**
     * The list of asset properties for the asset.
     *
     * This object doesn't include properties that you define in composite models. You can find composite model properties in the `assetCompositeModels` object.
     */
    readonly assetProperties: pulumi.Output<outputs.iotsitewise.AssetProperty[] | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the asset.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Asset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AssetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Asset resource.
 */
export interface AssetArgs {
    /**
     * A description for the asset
     */
    assetDescription?: pulumi.Input<string>;
    /**
     * The External ID of the asset
     */
    assetExternalId?: pulumi.Input<string>;
    /**
     * A list of asset hierarchies that each contain a `hierarchyId` . A hierarchy specifies allowed parent/child asset relationships.
     */
    assetHierarchies?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetHierarchyArgs>[]>;
    /**
     * The ID of the asset model from which to create the asset.
     */
    assetModelId: pulumi.Input<string>;
    /**
     * A unique, friendly name for the asset.
     */
    assetName?: pulumi.Input<string>;
    /**
     * The list of asset properties for the asset.
     *
     * This object doesn't include properties that you define in composite models. You can find composite model properties in the `assetCompositeModels` object.
     */
    assetProperties?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetPropertyArgs>[]>;
    /**
     * A list of key-value pairs that contain metadata for the asset.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
