import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::IoTTwinMaker::SyncJob
 */
export declare class SyncJob extends pulumi.CustomResource {
    /**
     * Get an existing SyncJob resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SyncJob;
    /**
     * Returns true if the given object is an instance of SyncJob.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SyncJob;
    /**
     * The ARN of the SyncJob.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The date and time when the sync job was created.
     */
    readonly creationDateTime: pulumi.Output<string>;
    /**
     * The state of SyncJob.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The IAM Role that execute SyncJob.
     */
    readonly syncRole: pulumi.Output<string>;
    /**
     * The source of the SyncJob.
     */
    readonly syncSource: pulumi.Output<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The date and time when the sync job was updated.
     */
    readonly updateDateTime: pulumi.Output<string>;
    /**
     * The ID of the workspace.
     */
    readonly workspaceId: pulumi.Output<string>;
    /**
     * Create a SyncJob resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SyncJobArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SyncJob resource.
 */
export interface SyncJobArgs {
    /**
     * The IAM Role that execute SyncJob.
     */
    syncRole: pulumi.Input<string>;
    /**
     * The source of the SyncJob.
     */
    syncSource: pulumi.Input<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the workspace.
     */
    workspaceId: pulumi.Input<string>;
}
