import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Create and manage NetworkAnalyzerConfiguration resource.
 */
export declare class NetworkAnalyzerConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing NetworkAnalyzerConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NetworkAnalyzerConfiguration;
    /**
     * Returns true if the given object is an instance of NetworkAnalyzerConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkAnalyzerConfiguration;
    /**
     * Arn for network analyzer configuration, Returned upon successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the new resource
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Name of the network analyzer configuration
     */
    readonly name: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Trace content for your wireless gateway and wireless device resources
     */
    readonly traceContent: pulumi.Output<outputs.iotwireless.TraceContentProperties | undefined>;
    /**
     * List of wireless gateway resources that have been added to the network analyzer configuration
     */
    readonly wirelessDevices: pulumi.Output<string[] | undefined>;
    /**
     * List of wireless gateway resources that have been added to the network analyzer configuration
     */
    readonly wirelessGateways: pulumi.Output<string[] | undefined>;
    /**
     * Create a NetworkAnalyzerConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: NetworkAnalyzerConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NetworkAnalyzerConfiguration resource.
 */
export interface NetworkAnalyzerConfigurationArgs {
    /**
     * The description of the new resource
     */
    description?: pulumi.Input<string>;
    /**
     * Name of the network analyzer configuration
     */
    name?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Trace content for your wireless gateway and wireless device resources
     */
    traceContent?: pulumi.Input<inputs.iotwireless.TraceContentPropertiesArgs>;
    /**
     * List of wireless gateway resources that have been added to the network analyzer configuration
     */
    wirelessDevices?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of wireless gateway resources that have been added to the network analyzer configuration
     */
    wirelessGateways?: pulumi.Input<pulumi.Input<string>[]>;
}
