import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Kinesis::StreamConsumer
 */
export declare class StreamConsumer extends pulumi.CustomResource {
    /**
     * Get an existing StreamConsumer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StreamConsumer;
    /**
     * Returns true if the given object is an instance of StreamConsumer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StreamConsumer;
    /**
     * The ARN returned by Kinesis Data Streams when you registered the consumer. If you don't know the ARN of the consumer that you want to deregister, you can use the ListStreamConsumers operation to get a list of the descriptions of all the consumers that are currently registered with a given data stream. The description of a consumer contains its ARN.
     */
    readonly consumerArn: pulumi.Output<string>;
    /**
     * Timestamp when the consumer was created.
     */
    readonly consumerCreationTimestamp: pulumi.Output<string>;
    /**
     * The name of the Kinesis Stream Consumer. For a given Kinesis data stream, each consumer must have a unique name. However, consumer names don't have to be unique across data streams.
     */
    readonly consumerName: pulumi.Output<string>;
    /**
     * A consumer can't read data while in the CREATING or DELETING states. Valid Values: CREATING | DELETING | ACTIVE
     */
    readonly consumerStatus: pulumi.Output<string>;
    /**
     * The Amazon resource name (ARN) of the Kinesis data stream that you want to register the consumer with.
     */
    readonly streamArn: pulumi.Output<string>;
    /**
     * An arbitrary set of tags (key–value pairs) to associate with the Kinesis consumer.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a StreamConsumer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StreamConsumerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StreamConsumer resource.
 */
export interface StreamConsumerArgs {
    /**
     * The name of the Kinesis Stream Consumer. For a given Kinesis data stream, each consumer must have a unique name. However, consumer names don't have to be unique across data streams.
     */
    consumerName?: pulumi.Input<string>;
    /**
     * The Amazon resource name (ARN) of the Kinesis data stream that you want to register the consumer with.
     */
    streamArn: pulumi.Input<string>;
    /**
     * An arbitrary set of tags (key–value pairs) to associate with the Kinesis consumer.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
