import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lightsail::InstanceSnapshot
 */
export declare class InstanceSnapshot extends pulumi.CustomResource {
    /**
     * Get an existing InstanceSnapshot resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InstanceSnapshot;
    /**
     * Returns true if the given object is an instance of InstanceSnapshot.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InstanceSnapshot;
    /**
     * The Amazon Resource Name (ARN) of the snapshot.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the instance from which the snapshot was created.
     */
    readonly fromInstanceArn: pulumi.Output<string>;
    /**
     * The instance from which the snapshot was created.
     */
    readonly fromInstanceName: pulumi.Output<string>;
    /**
     * The instance from which the snapshot was created.
     */
    readonly instanceName: pulumi.Output<string>;
    /**
     * The name of the snapshot.
     */
    readonly instanceSnapshotName: pulumi.Output<string>;
    /**
     * A Boolean value indicating whether the snapshot was created from an automatic snapshot.
     */
    readonly isFromAutoSnapshot: pulumi.Output<boolean>;
    readonly location: pulumi.Output<outputs.lightsail.InstanceSnapshotLocation>;
    /**
     * The type of resource (usually InstanceSnapshot).
     */
    readonly resourceType: pulumi.Output<string>;
    /**
     * The size in GB of the SSD
     */
    readonly sizeInGb: pulumi.Output<number>;
    /**
     * The state the snapshot is in.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Support code to help identify any issues
     */
    readonly supportCode: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a InstanceSnapshot resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InstanceSnapshotArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InstanceSnapshot resource.
 */
export interface InstanceSnapshotArgs {
    /**
     * The instance from which the snapshot was created.
     */
    instanceName: pulumi.Input<string>;
    /**
     * The name of the snapshot.
     */
    instanceSnapshotName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
