import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * This structure contains information about one delivery destination in your account.
 *
 * A delivery destination is an AWS resource that represents an AWS service that logs can be sent to CloudWatch Logs, Amazon S3, are supported as Kinesis Data Firehose delivery destinations.
 */
export declare class DeliveryDestination extends pulumi.CustomResource {
    /**
     * Get an existing DeliveryDestination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DeliveryDestination;
    /**
     * Returns true if the given object is an instance of DeliveryDestination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DeliveryDestination;
    /**
     * The Amazon Resource Name (ARN) that uniquely identifies this delivery destination.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * IAM policy that grants permissions to CloudWatch Logs to deliver logs cross-account to a specified destination in this account.
     *
     * The policy must be in JSON string format.
     *
     * Length Constraints: Maximum length of 51200
     */
    readonly deliveryDestinationPolicy: pulumi.Output<outputs.logs.DeliveryDestinationDestinationPolicy | undefined>;
    /**
     * Displays whether this delivery destination is CloudWatch Logs, Amazon S3, or Kinesis Data Firehose.
     */
    readonly deliveryDestinationType: pulumi.Output<string>;
    /**
     * The ARN of the Amazon Web Services destination that this delivery destination represents. That Amazon Web Services destination can be a log group in CloudWatch Logs, an Amazon S3 bucket, or a delivery stream in Firehose.
     */
    readonly destinationResourceArn: pulumi.Output<string | undefined>;
    /**
     * The name of this delivery destination.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The format of the logs that are sent to this delivery destination.
     */
    readonly outputFormat: pulumi.Output<string | undefined>;
    /**
     * The tags that have been assigned to this delivery destination.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DeliveryDestination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DeliveryDestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DeliveryDestination resource.
 */
export interface DeliveryDestinationArgs {
    /**
     * IAM policy that grants permissions to CloudWatch Logs to deliver logs cross-account to a specified destination in this account.
     *
     * The policy must be in JSON string format.
     *
     * Length Constraints: Maximum length of 51200
     */
    deliveryDestinationPolicy?: pulumi.Input<inputs.logs.DeliveryDestinationDestinationPolicyArgs>;
    /**
     * The ARN of the Amazon Web Services destination that this delivery destination represents. That Amazon Web Services destination can be a log group in CloudWatch Logs, an Amazon S3 bucket, or a delivery stream in Firehose.
     */
    destinationResourceArn?: pulumi.Input<string>;
    /**
     * The name of this delivery destination.
     */
    name?: pulumi.Input<string>;
    /**
     * The format of the logs that are sent to this delivery destination.
     */
    outputFormat?: pulumi.Input<string>;
    /**
     * The tags that have been assigned to this delivery destination.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
