import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Macie CustomDataIdentifier resource schema
 */
export declare class CustomDataIdentifier extends pulumi.CustomResource {
    /**
     * Get an existing CustomDataIdentifier resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CustomDataIdentifier;
    /**
     * Returns true if the given object is an instance of CustomDataIdentifier.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomDataIdentifier;
    /**
     * Custom data identifier ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Custom data identifier ID.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Description of custom data identifier.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Words to be ignored.
     */
    readonly ignoreWords: pulumi.Output<string[] | undefined>;
    /**
     * Keywords to be matched against.
     */
    readonly keywords: pulumi.Output<string[] | undefined>;
    /**
     * Maximum match distance.
     */
    readonly maximumMatchDistance: pulumi.Output<number | undefined>;
    /**
     * Name of custom data identifier.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Regular expression for custom data identifier.
     */
    readonly regex: pulumi.Output<string>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CustomDataIdentifier resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomDataIdentifierArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CustomDataIdentifier resource.
 */
export interface CustomDataIdentifierArgs {
    /**
     * Description of custom data identifier.
     */
    description?: pulumi.Input<string>;
    /**
     * Words to be ignored.
     */
    ignoreWords?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Keywords to be matched against.
     */
    keywords?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Maximum match distance.
     */
    maximumMatchDistance?: pulumi.Input<number>;
    /**
     * Name of custom data identifier.
     */
    name?: pulumi.Input<string>;
    /**
     * Regular expression for custom data identifier.
     */
    regex: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
