import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::MediaConnect::FlowVpcInterface
 */
export declare class FlowVpcInterface extends pulumi.CustomResource {
    /**
     * Get an existing FlowVpcInterface resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FlowVpcInterface;
    /**
     * Returns true if the given object is an instance of FlowVpcInterface.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FlowVpcInterface;
    /**
     * The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the flow.
     */
    readonly flowArn: pulumi.Output<string>;
    /**
     * Immutable and has to be a unique against other VpcInterfaces in this Flow.
     */
    readonly name: pulumi.Output<string>;
    /**
     * IDs of the network interfaces created in customer's account by MediaConnect.
     */
    readonly networkInterfaceIds: pulumi.Output<string[]>;
    /**
     * Role Arn MediaConnect can assume to create ENIs in customer's account.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Security Group IDs to be used on ENI.
     */
    readonly securityGroupIds: pulumi.Output<string[]>;
    /**
     * Subnet must be in the AZ of the Flow
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * Create a FlowVpcInterface resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FlowVpcInterfaceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FlowVpcInterface resource.
 */
export interface FlowVpcInterfaceArgs {
    /**
     * The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the flow.
     */
    flowArn: pulumi.Input<string>;
    /**
     * Immutable and has to be a unique against other VpcInterfaces in this Flow.
     */
    name?: pulumi.Input<string>;
    /**
     * Role Arn MediaConnect can assume to create ENIs in customer's account.
     */
    roleArn: pulumi.Input<string>;
    /**
     * Security Group IDs to be used on ENI.
     */
    securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Subnet must be in the AZ of the Flow
     */
    subnetId: pulumi.Input<string>;
}
