import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Definition of AWS::MediaLive::CloudWatchAlarmTemplate Resource Type
 */
export declare function getCloudWatchAlarmTemplate(args: GetCloudWatchAlarmTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudWatchAlarmTemplateResult>;
export interface GetCloudWatchAlarmTemplateArgs {
    identifier: string;
}
export interface GetCloudWatchAlarmTemplateResult {
    /**
     * A cloudwatch alarm template's ARN (Amazon Resource Name)
     */
    readonly arn?: string;
    /**
     * The comparison operator used to compare the specified statistic and the threshold.
     */
    readonly comparisonOperator?: enums.medialive.CloudWatchAlarmTemplateComparisonOperator;
    /**
     * The date and time of resource creation.
     */
    readonly createdAt?: string;
    /**
     * The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
     */
    readonly datapointsToAlarm?: number;
    /**
     * A resource's optional description.
     */
    readonly description?: string;
    /**
     * The number of periods over which data is compared to the specified threshold.
     */
    readonly evaluationPeriods?: number;
    /**
     * A cloudwatch alarm template group's id. AWS provided template groups have ids that start with `aws-`
     */
    readonly groupId?: string;
    /**
     * A cloudwatch alarm template's id. AWS provided templates have ids that start with `aws-`
     */
    readonly id?: string;
    readonly identifier?: string;
    /**
     * The name of the metric associated with the alarm. Must be compatible with targetResourceType.
     */
    readonly metricName?: string;
    /**
     * The date and time of latest resource modification.
     */
    readonly modifiedAt?: string;
    /**
     * A resource's name. Names must be unique within the scope of a resource type in a specific region.
     */
    readonly name?: string;
    /**
     * The period, in seconds, over which the specified statistic is applied.
     */
    readonly period?: number;
    /**
     * The statistic to apply to the alarm's metric data.
     */
    readonly statistic?: enums.medialive.CloudWatchAlarmTemplateStatistic;
    /**
     * The resource type this template should dynamically generate CloudWatch metric alarms for.
     */
    readonly targetResourceType?: enums.medialive.CloudWatchAlarmTemplateTargetResourceType;
    /**
     * The threshold value to compare with the specified statistic.
     */
    readonly threshold?: number;
    /**
     * Specifies how missing data points are treated when evaluating the alarm's condition.
     */
    readonly treatMissingData?: enums.medialive.CloudWatchAlarmTemplateTreatMissingData;
}
/**
 * Definition of AWS::MediaLive::CloudWatchAlarmTemplate Resource Type
 */
export declare function getCloudWatchAlarmTemplateOutput(args: GetCloudWatchAlarmTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudWatchAlarmTemplateResult>;
export interface GetCloudWatchAlarmTemplateOutputArgs {
    identifier: pulumi.Input<string>;
}
