import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::MSK::Replicator
 */
export declare class Replicator extends pulumi.CustomResource {
    /**
     * Get an existing Replicator resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Replicator;
    /**
     * Returns true if the given object is an instance of Replicator.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Replicator;
    /**
     * The current version of the MSK replicator.
     */
    readonly currentVersion: pulumi.Output<string>;
    /**
     * A summary description of the replicator.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Specifies a list of Kafka clusters which are targets of the replicator.
     */
    readonly kafkaClusters: pulumi.Output<outputs.msk.ReplicatorKafkaCluster[]>;
    /**
     * A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
     */
    readonly replicationInfoList: pulumi.Output<outputs.msk.ReplicatorReplicationInfo[]>;
    /**
     * Amazon Resource Name for the created replicator.
     */
    readonly replicatorArn: pulumi.Output<string>;
    /**
     * The name of the replicator.
     */
    readonly replicatorName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role used by the replicator to access external resources.
     */
    readonly serviceExecutionRoleArn: pulumi.Output<string>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Replicator resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicatorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Replicator resource.
 */
export interface ReplicatorArgs {
    /**
     * A summary description of the replicator.
     */
    description?: pulumi.Input<string>;
    /**
     * Specifies a list of Kafka clusters which are targets of the replicator.
     */
    kafkaClusters: pulumi.Input<pulumi.Input<inputs.msk.ReplicatorKafkaClusterArgs>[]>;
    /**
     * A list of replication configurations, where each configuration targets a given source cluster to target cluster replication flow.
     */
    replicationInfoList: pulumi.Input<pulumi.Input<inputs.msk.ReplicatorReplicationInfoArgs>[]>;
    /**
     * The name of the replicator.
     */
    replicatorName?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role used by the replicator to access external resources.
     */
    serviceExecutionRoleArn: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
