import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::Neptune::DBSubnetGroup type creates an Amazon Neptune DB subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same AWS Region.
 */
export declare function getDbSubnetGroup(args: GetDbSubnetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetDbSubnetGroupResult>;
export interface GetDbSubnetGroupArgs {
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *
     * Constraints: Must contain no more than 255 lowercase alphanumeric characters or hyphens. Must not be "Default".
     *
     * Example: mysubnetgroup
     */
    dbSubnetGroupName: string;
}
export interface GetDbSubnetGroupResult {
    /**
     * The description for the DB subnet group.
     */
    readonly dbSubnetGroupDescription?: string;
    /**
     * The Amazon EC2 subnet IDs for the DB subnet group.
     */
    readonly subnetIds?: string[];
    /**
     * An optional array of key-value pairs to apply to this DB subnet group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::Neptune::DBSubnetGroup type creates an Amazon Neptune DB subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same AWS Region.
 */
export declare function getDbSubnetGroupOutput(args: GetDbSubnetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbSubnetGroupResult>;
export interface GetDbSubnetGroupOutputArgs {
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *
     * Constraints: Must contain no more than 255 lowercase alphanumeric characters or hyphens. Must not be "Default".
     *
     * Example: mysubnetgroup
     */
    dbSubnetGroupName: pulumi.Input<string>;
}
