import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource type definition for AWS::NetworkFirewall::RuleGroup
 */
export declare class RuleGroup extends pulumi.CustomResource {
    /**
     * Get an existing RuleGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RuleGroup;
    /**
     * Returns true if the given object is an instance of RuleGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RuleGroup;
    /**
     * The maximum operating resources that this rule group can use. You can't change a rule group's capacity setting after you create the rule group. When you update a rule group, you are limited to this capacity. When you reference a rule group from a firewall policy, Network Firewall reserves this capacity for the rule group.
     */
    readonly capacity: pulumi.Output<number>;
    /**
     * A description of the rule group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * An object that defines the rule group rules.
     */
    readonly ruleGroup: pulumi.Output<outputs.networkfirewall.RuleGroup | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the `RuleGroup` .
     */
    readonly ruleGroupArn: pulumi.Output<string>;
    /**
     * The unique ID of the `RuleGroup` resource.
     */
    readonly ruleGroupId: pulumi.Output<string>;
    /**
     * The descriptive name of the rule group. You can't change the name of a rule group after you create it.
     */
    readonly ruleGroupName: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains
     * stateless rules. If it is stateful, it contains stateful rules.
     */
    readonly type: pulumi.Output<enums.networkfirewall.RuleGroupTypeEnum>;
    /**
     * Create a RuleGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RuleGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RuleGroup resource.
 */
export interface RuleGroupArgs {
    /**
     * The maximum operating resources that this rule group can use. You can't change a rule group's capacity setting after you create the rule group. When you update a rule group, you are limited to this capacity. When you reference a rule group from a firewall policy, Network Firewall reserves this capacity for the rule group.
     */
    capacity: pulumi.Input<number>;
    /**
     * A description of the rule group.
     */
    description?: pulumi.Input<string>;
    /**
     * An object that defines the rule group rules.
     */
    ruleGroup?: pulumi.Input<inputs.networkfirewall.RuleGroupArgs>;
    /**
     * The descriptive name of the rule group. You can't change the name of a rule group after you create it.
     */
    ruleGroupName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains
     * stateless rules. If it is stateful, it contains stateful rules.
     */
    type: pulumi.Input<enums.networkfirewall.RuleGroupTypeEnum>;
}
