import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::NetworkManager::ConnectAttachment Resource Type Definition
 */
export declare class ConnectAttachment extends pulumi.CustomResource {
    /**
     * Get an existing ConnectAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConnectAttachment;
    /**
     * Returns true if the given object is an instance of ConnectAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConnectAttachment;
    /**
     * The ID of the attachment.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * The policy rule number associated with the attachment.
     */
    readonly attachmentPolicyRuleNumber: pulumi.Output<number>;
    /**
     * The type of attachment.
     */
    readonly attachmentType: pulumi.Output<string>;
    /**
     * The ARN of a core network.
     */
    readonly coreNetworkArn: pulumi.Output<string>;
    /**
     * ID of the CoreNetwork that the attachment will be attached to.
     */
    readonly coreNetworkId: pulumi.Output<string>;
    /**
     * Creation time of the attachment.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Edge location of the attachment.
     */
    readonly edgeLocation: pulumi.Output<string>;
    /**
     * The name of the network function group attachment.
     */
    readonly networkFunctionGroupName: pulumi.Output<string | undefined>;
    /**
     * Protocol options for connect attachment
     */
    readonly options: pulumi.Output<outputs.networkmanager.ConnectAttachmentOptions>;
    /**
     * The ID of the attachment account owner.
     */
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    readonly proposedNetworkFunctionGroupChange: pulumi.Output<outputs.networkmanager.ConnectAttachmentProposedNetworkFunctionGroupChange | undefined>;
    /**
     * The attachment to move from one segment to another.
     */
    readonly proposedSegmentChange: pulumi.Output<outputs.networkmanager.ConnectAttachmentProposedSegmentChange | undefined>;
    /**
     * The attachment resource ARN.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The name of the segment attachment.
     */
    readonly segmentName: pulumi.Output<string>;
    /**
     * State of the attachment.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Tags for the attachment.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Id of transport attachment
     */
    readonly transportAttachmentId: pulumi.Output<string>;
    /**
     * Last update time of the attachment.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a ConnectAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConnectAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConnectAttachment resource.
 */
export interface ConnectAttachmentArgs {
    /**
     * ID of the CoreNetwork that the attachment will be attached to.
     */
    coreNetworkId: pulumi.Input<string>;
    /**
     * Edge location of the attachment.
     */
    edgeLocation: pulumi.Input<string>;
    /**
     * The name of the network function group attachment.
     */
    networkFunctionGroupName?: pulumi.Input<string>;
    /**
     * Protocol options for connect attachment
     */
    options: pulumi.Input<inputs.networkmanager.ConnectAttachmentOptionsArgs>;
    /**
     * The attachment to move from one network function group to another.
     */
    proposedNetworkFunctionGroupChange?: pulumi.Input<inputs.networkmanager.ConnectAttachmentProposedNetworkFunctionGroupChangeArgs>;
    /**
     * The attachment to move from one segment to another.
     */
    proposedSegmentChange?: pulumi.Input<inputs.networkmanager.ConnectAttachmentProposedSegmentChangeArgs>;
    /**
     * Tags for the attachment.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Id of transport attachment
     */
    transportAttachmentId: pulumi.Input<string>;
}
