import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::ODB::CloudVmCluster resource creates a Cloud VM Cluster
 */
export declare class CloudVmCluster extends pulumi.CustomResource {
    /**
     * Get an existing CloudVmCluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CloudVmCluster;
    /**
     * Returns true if the given object is an instance of CloudVmCluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudVmCluster;
    /**
     * The unique identifier of the Exadata infrastructure that this VM cluster belongs to.
     */
    readonly cloudExadataInfrastructureId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the VM cluster.
     */
    readonly cloudVmClusterArn: pulumi.Output<string>;
    /**
     * The unique identifier of the VM cluster.
     */
    readonly cloudVmClusterId: pulumi.Output<string>;
    /**
     * The name of the Grid Infrastructure (GI) cluster.
     */
    readonly clusterName: pulumi.Output<string | undefined>;
    /**
     * The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.
     */
    readonly computeModel: pulumi.Output<string>;
    /**
     * The number of CPU cores enabled on the VM cluster.
     */
    readonly cpuCoreCount: pulumi.Output<number | undefined>;
    /**
     * The set of diagnostic collection options enabled for the VM cluster.
     */
    readonly dataCollectionOptions: pulumi.Output<outputs.odb.CloudVmClusterDataCollectionOptions | undefined>;
    /**
     * The size of the data disk group, in terabytes (TB), that's allocated for the VM cluster.
     */
    readonly dataStorageSizeInTbs: pulumi.Output<number | undefined>;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated for the VM cluster.
     */
    readonly dbNodeStorageSizeInGbs: pulumi.Output<number | undefined>;
    /**
     * The list of database servers for the VM cluster.
     */
    readonly dbServers: pulumi.Output<string[] | undefined>;
    /**
     * The type of redundancy configured for the VM cluster. NORMAL is 2-way redundancy. HIGH is 3-way redundancy.
     */
    readonly diskRedundancy: pulumi.Output<string>;
    /**
     * The user-friendly name for the VM cluster.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The domain of the VM cluster.
     */
    readonly domain: pulumi.Output<string>;
    /**
     * The software version of the Oracle Grid Infrastructure (GI) for the VM cluster.
     */
    readonly giVersion: pulumi.Output<string | undefined>;
    /**
     * The host name for the VM cluster.
     */
    readonly hostname: pulumi.Output<string | undefined>;
    /**
     * Indicates whether database backups to local Exadata storage is enabled for the VM cluster.
     */
    readonly isLocalBackupEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Indicates whether the VM cluster is configured with a sparse disk group.
     */
    readonly isSparseDiskgroupEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The Oracle license model applied to the VM cluster.
     */
    readonly licenseModel: pulumi.Output<enums.odb.CloudVmClusterLicenseModel | undefined>;
    /**
     * The port number configured for the listener on the VM cluster.
     */
    readonly listenerPort: pulumi.Output<number>;
    /**
     * The amount of memory, in gigabytes (GB), that's allocated for the VM cluster.
     */
    readonly memorySizeInGbs: pulumi.Output<number | undefined>;
    /**
     * The number of nodes in the VM cluster.
     */
    readonly nodeCount: pulumi.Output<number>;
    /**
     * The name of the OCI resource anchor for the VM cluster.
     */
    readonly ociResourceAnchorName: pulumi.Output<string>;
    /**
     * The HTTPS link to the VM cluster in OCI.
     */
    readonly ociUrl: pulumi.Output<string>;
    /**
     * The OCID of the VM cluster.
     */
    readonly ocid: pulumi.Output<string>;
    /**
     * The unique identifier of the ODB network for the VM cluster.
     */
    readonly odbNetworkId: pulumi.Output<string | undefined>;
    /**
     * The FQDN of the DNS record for the Single Client Access Name (SCAN) IP addresses that are associated with the VM cluster.
     */
    readonly scanDnsName: pulumi.Output<string>;
    /**
     * The OCID of the SCAN IP addresses that are associated with the VM cluster.
     */
    readonly scanIpIds: pulumi.Output<string[]>;
    /**
     * Property description not available.
     */
    readonly scanListenerPortTcp: pulumi.Output<number | undefined>;
    /**
     * The hardware model name of the Exadata infrastructure that's running the VM cluster.
     */
    readonly shape: pulumi.Output<string>;
    /**
     * The public key portion of one or more key pairs used for SSH access to the VM cluster.
     */
    readonly sshPublicKeys: pulumi.Output<string[] | undefined>;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated to the VM cluster.
     */
    readonly storageSizeInGbs: pulumi.Output<number>;
    /**
     * The operating system version of the image chosen for the VM cluster.
     */
    readonly systemVersion: pulumi.Output<string | undefined>;
    /**
     * Tags to assign to the Vm Cluster.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The time zone of the VM cluster.
     */
    readonly timeZone: pulumi.Output<string | undefined>;
    /**
     * The virtual IP (VIP) addresses that are associated with the VM cluster. Oracle's Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the VM cluster to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.
     */
    readonly vipIds: pulumi.Output<string[]>;
    /**
     * Create a CloudVmCluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: CloudVmClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CloudVmCluster resource.
 */
export interface CloudVmClusterArgs {
    /**
     * The unique identifier of the Exadata infrastructure that this VM cluster belongs to.
     */
    cloudExadataInfrastructureId?: pulumi.Input<string>;
    /**
     * The name of the Grid Infrastructure (GI) cluster.
     */
    clusterName?: pulumi.Input<string>;
    /**
     * The number of CPU cores enabled on the VM cluster.
     */
    cpuCoreCount?: pulumi.Input<number>;
    /**
     * The set of diagnostic collection options enabled for the VM cluster.
     */
    dataCollectionOptions?: pulumi.Input<inputs.odb.CloudVmClusterDataCollectionOptionsArgs>;
    /**
     * The size of the data disk group, in terabytes (TB), that's allocated for the VM cluster.
     */
    dataStorageSizeInTbs?: pulumi.Input<number>;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated for the VM cluster.
     */
    dbNodeStorageSizeInGbs?: pulumi.Input<number>;
    /**
     * The list of database servers for the VM cluster.
     */
    dbServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The user-friendly name for the VM cluster.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The software version of the Oracle Grid Infrastructure (GI) for the VM cluster.
     */
    giVersion?: pulumi.Input<string>;
    /**
     * The host name for the VM cluster.
     */
    hostname?: pulumi.Input<string>;
    /**
     * Indicates whether database backups to local Exadata storage is enabled for the VM cluster.
     */
    isLocalBackupEnabled?: pulumi.Input<boolean>;
    /**
     * Indicates whether the VM cluster is configured with a sparse disk group.
     */
    isSparseDiskgroupEnabled?: pulumi.Input<boolean>;
    /**
     * The Oracle license model applied to the VM cluster.
     */
    licenseModel?: pulumi.Input<enums.odb.CloudVmClusterLicenseModel>;
    /**
     * The amount of memory, in gigabytes (GB), that's allocated for the VM cluster.
     */
    memorySizeInGbs?: pulumi.Input<number>;
    /**
     * The unique identifier of the ODB network for the VM cluster.
     */
    odbNetworkId?: pulumi.Input<string>;
    /**
     * Property description not available.
     */
    scanListenerPortTcp?: pulumi.Input<number>;
    /**
     * The public key portion of one or more key pairs used for SSH access to the VM cluster.
     */
    sshPublicKeys?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The operating system version of the image chosen for the VM cluster.
     */
    systemVersion?: pulumi.Input<string>;
    /**
     * Tags to assign to the Vm Cluster.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The time zone of the VM cluster.
     */
    timeZone?: pulumi.Input<string>;
}
