import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The AWS::ODB::CloudAutonomousVmCluster resource creates a Cloud Autonomous VM Cluster
 */
export declare function getCloudAutonomousVmCluster(args: GetCloudAutonomousVmClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudAutonomousVmClusterResult>;
export interface GetCloudAutonomousVmClusterArgs {
    /**
     * The Amazon Resource Name (ARN) for the Autonomous VM cluster.
     */
    cloudAutonomousVmClusterArn: string;
}
export interface GetCloudAutonomousVmClusterResult {
    /**
     * The percentage of data storage currently in use for Autonomous Databases in the Autonomous VM cluster.
     */
    readonly autonomousDataStoragePercentage?: number;
    /**
     * The available data storage space for Autonomous Databases in the Autonomous VM cluster, in TB.
     */
    readonly availableAutonomousDataStorageSizeInTbs?: number;
    /**
     * The number of Autonomous CDBs that you can create with the currently available storage.
     */
    readonly availableContainerDatabases?: number;
    /**
     * The number of CPU cores available for allocation to Autonomous Databases.
     */
    readonly availableCpus?: number;
    /**
     * The Amazon Resource Name (ARN) for the Autonomous VM cluster.
     */
    readonly cloudAutonomousVmClusterArn?: string;
    /**
     * The unique identifier of the Autonomous VM cluster.
     */
    readonly cloudAutonomousVmClusterId?: string;
    /**
     * The compute model of the Autonomous VM cluster: ECPU or OCPU.
     */
    readonly computeModel?: enums.odb.CloudAutonomousVmClusterComputeModel;
    /**
     * The total number of CPU cores in the Autonomous VM cluster.
     */
    readonly cpuCoreCount?: number;
    /**
     * The percentage of total CPU cores currently in use in the Autonomous VM cluster.
     */
    readonly cpuPercentage?: number;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in GB.
     */
    readonly dataStorageSizeInGbs?: number;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in TB.
     */
    readonly dataStorageSizeInTbs?: number;
    /**
     * The local node storage allocated to the Autonomous VM cluster, in gigabytes (GB).
     */
    readonly dbNodeStorageSizeInGbs?: number;
    /**
     * The domain name for the Autonomous VM cluster.
     */
    readonly domain?: string;
    /**
     * The minimum value to which you can scale down the Exadata storage, in TB.
     */
    readonly exadataStorageInTbsLowestScaledValue?: number;
    /**
     * The hostname for the Autonomous VM cluster.
     */
    readonly hostname?: string;
    /**
     * The minimum value to which you can scale down the maximum number of Autonomous CDBs.
     */
    readonly maxAcdsLowestScaledValue?: number;
    /**
     * The total amount of memory allocated to the Autonomous VM cluster, in gigabytes (GB).
     */
    readonly memorySizeInGbs?: number;
    /**
     * The number of database server nodes in the Autonomous VM cluster.
     */
    readonly nodeCount?: number;
    /**
     * The number of Autonomous CDBs that can't be provisioned because of resource constraints.
     */
    readonly nonProvisionableAutonomousContainerDatabases?: number;
    /**
     * The name of the OCI resource anchor associated with this Autonomous VM cluster.
     */
    readonly ociResourceAnchorName?: string;
    /**
     * The URL for accessing the OCI console page for this Autonomous VM cluster.
     */
    readonly ociUrl?: string;
    /**
     * The Oracle Cloud Identifier (OCID) of the Autonomous VM cluster.
     */
    readonly ocid?: string;
    /**
     * The number of Autonomous CDBs that can be provisioned in the Autonomous VM cluster.
     */
    readonly provisionableAutonomousContainerDatabases?: number;
    /**
     * The number of Autonomous CDBs currently provisioned in the Autonomous VM cluster.
     */
    readonly provisionedAutonomousContainerDatabases?: number;
    /**
     * The number of CPU cores currently provisioned in the Autonomous VM cluster.
     */
    readonly provisionedCpus?: number;
    /**
     * The number of CPU cores that can be reclaimed from terminated or scaled-down Autonomous Databases.
     */
    readonly reclaimableCpus?: number;
    /**
     * The number of CPU cores reserved for system operations and redundancy.
     */
    readonly reservedCpus?: number;
    /**
     * The shape of the Exadata infrastructure for the Autonomous VM cluster.
     */
    readonly shape?: string;
    /**
     * The tags associated with the Autonomous VM cluster.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::ODB::CloudAutonomousVmCluster resource creates a Cloud Autonomous VM Cluster
 */
export declare function getCloudAutonomousVmClusterOutput(args: GetCloudAutonomousVmClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudAutonomousVmClusterResult>;
export interface GetCloudAutonomousVmClusterOutputArgs {
    /**
     * The Amazon Resource Name (ARN) for the Autonomous VM cluster.
     */
    cloudAutonomousVmClusterArn: pulumi.Input<string>;
}
