import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::ODB::OdbNetwork resource creates an ODB Network
 */
export declare class OdbNetwork extends pulumi.CustomResource {
    /**
     * Get an existing OdbNetwork resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OdbNetwork;
    /**
     * Returns true if the given object is an instance of OdbNetwork.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OdbNetwork;
    /**
     * The AWS Availability Zone (AZ) where the ODB network is located.
     */
    readonly availabilityZone: pulumi.Output<string | undefined>;
    /**
     * The AZ ID of the AZ where the ODB network is located.
     */
    readonly availabilityZoneId: pulumi.Output<string | undefined>;
    /**
     * The CIDR range of the backup subnet in the ODB network.
     */
    readonly backupSubnetCidr: pulumi.Output<string | undefined>;
    /**
     * The CIDR range of the client subnet in the ODB network.
     */
    readonly clientSubnetCidr: pulumi.Output<string | undefined>;
    /**
     * The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.
     */
    readonly defaultDnsPrefix: pulumi.Output<string | undefined>;
    /**
     * Specifies whether to delete associated OCI networking resources along with the ODB network.
     */
    readonly deleteAssociatedResources: pulumi.Output<boolean | undefined>;
    /**
     * The user-friendly name of the ODB network.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The unique identifier of the OCI network anchor for the ODB network.
     */
    readonly ociNetworkAnchorId: pulumi.Output<string>;
    /**
     * The name of the OCI resource anchor that's associated with the ODB network.
     */
    readonly ociResourceAnchorName: pulumi.Output<string>;
    /**
     * The URL for the VCN that's associated with the ODB network.
     */
    readonly ociVcnUrl: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the ODB network.
     */
    readonly odbNetworkArn: pulumi.Output<string>;
    /**
     * The unique identifier of the ODB network.
     */
    readonly odbNetworkId: pulumi.Output<string>;
    /**
     * Tags to assign to the Odb Network.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a OdbNetwork resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: OdbNetworkArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OdbNetwork resource.
 */
export interface OdbNetworkArgs {
    /**
     * The AWS Availability Zone (AZ) where the ODB network is located.
     */
    availabilityZone?: pulumi.Input<string>;
    /**
     * The AZ ID of the AZ where the ODB network is located.
     */
    availabilityZoneId?: pulumi.Input<string>;
    /**
     * The CIDR range of the backup subnet in the ODB network.
     */
    backupSubnetCidr?: pulumi.Input<string>;
    /**
     * The CIDR range of the client subnet in the ODB network.
     */
    clientSubnetCidr?: pulumi.Input<string>;
    /**
     * The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.
     */
    defaultDnsPrefix?: pulumi.Input<string>;
    /**
     * Specifies whether to delete associated OCI networking resources along with the ODB network.
     */
    deleteAssociatedResources?: pulumi.Input<boolean>;
    /**
     * The user-friendly name of the ODB network.
     */
    displayName?: pulumi.Input<string>;
    /**
     * Tags to assign to the Odb Network.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
