import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Omics::WorkflowVersion Resource Type.
 */
export declare class WorkflowVersion extends pulumi.CustomResource {
    /**
     * Get an existing WorkflowVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WorkflowVersion;
    /**
     * Returns true if the given object is an instance of WorkflowVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkflowVersion;
    readonly accelerators: pulumi.Output<enums.omics.WorkflowVersionAccelerators | undefined>;
    /**
     * ARN of the workflow version.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The creation time of the workflow version.
     */
    readonly creationTime: pulumi.Output<string>;
    readonly definitionUri: pulumi.Output<string | undefined>;
    /**
     * The description of the workflow version.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly engine: pulumi.Output<enums.omics.WorkflowVersionWorkflowEngine | undefined>;
    readonly main: pulumi.Output<string | undefined>;
    readonly parameterTemplate: pulumi.Output<{
        [key: string]: outputs.omics.WorkflowVersionWorkflowParameter;
    } | undefined>;
    /**
     * The status of the workflow version.
     */
    readonly status: pulumi.Output<enums.omics.WorkflowVersionWorkflowStatus>;
    readonly storageCapacity: pulumi.Output<number | undefined>;
    readonly storageType: pulumi.Output<enums.omics.WorkflowVersionStorageType | undefined>;
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The type of the workflow version.
     */
    readonly type: pulumi.Output<enums.omics.WorkflowVersionWorkflowType>;
    readonly uuid: pulumi.Output<string>;
    /**
     * The name of the workflow version.
     */
    readonly versionName: pulumi.Output<string>;
    readonly workflowBucketOwnerId: pulumi.Output<string | undefined>;
    /**
     * The workflow's ID.
     */
    readonly workflowId: pulumi.Output<string>;
    /**
     * Create a WorkflowVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WorkflowVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WorkflowVersion resource.
 */
export interface WorkflowVersionArgs {
    accelerators?: pulumi.Input<enums.omics.WorkflowVersionAccelerators>;
    definitionUri?: pulumi.Input<string>;
    /**
     * The description of the workflow version.
     */
    description?: pulumi.Input<string>;
    engine?: pulumi.Input<enums.omics.WorkflowVersionWorkflowEngine>;
    main?: pulumi.Input<string>;
    parameterTemplate?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.omics.WorkflowVersionWorkflowParameterArgs>;
    }>;
    storageCapacity?: pulumi.Input<number>;
    storageType?: pulumi.Input<enums.omics.WorkflowVersionStorageType>;
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The name of the workflow version.
     */
    versionName?: pulumi.Input<string>;
    workflowBucketOwnerId?: pulumi.Input<string>;
    /**
     * The workflow's ID.
     */
    workflowId: pulumi.Input<string>;
}
