import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::PCAConnectorAD::TemplateGroupAccessControlEntry Resource Type
 */
export declare class TemplateGroupAccessControlEntry extends pulumi.CustomResource {
    /**
     * Get an existing TemplateGroupAccessControlEntry resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TemplateGroupAccessControlEntry;
    /**
     * Returns true if the given object is an instance of TemplateGroupAccessControlEntry.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TemplateGroupAccessControlEntry;
    /**
     * Permissions to allow or deny an Active Directory group to enroll or autoenroll certificates issued against a template.
     */
    readonly accessRights: pulumi.Output<outputs.pcaconnectorad.TemplateGroupAccessControlEntryAccessRights>;
    /**
     * Name of the Active Directory group. This name does not need to match the group name in Active Directory.
     */
    readonly groupDisplayName: pulumi.Output<string>;
    /**
     * Security identifier (SID) of the group object from Active Directory. The SID starts with "S-".
     */
    readonly groupSecurityIdentifier: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateTemplate](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateTemplate.html) .
     */
    readonly templateArn: pulumi.Output<string | undefined>;
    /**
     * Create a TemplateGroupAccessControlEntry resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TemplateGroupAccessControlEntryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TemplateGroupAccessControlEntry resource.
 */
export interface TemplateGroupAccessControlEntryArgs {
    /**
     * Permissions to allow or deny an Active Directory group to enroll or autoenroll certificates issued against a template.
     */
    accessRights: pulumi.Input<inputs.pcaconnectorad.TemplateGroupAccessControlEntryAccessRightsArgs>;
    /**
     * Name of the Active Directory group. This name does not need to match the group name in Active Directory.
     */
    groupDisplayName: pulumi.Input<string>;
    /**
     * Security identifier (SID) of the group object from Active Directory. The SID starts with "S-".
     */
    groupSecurityIdentifier?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateTemplate](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateTemplate.html) .
     */
    templateArn?: pulumi.Input<string>;
}
