import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::QBusiness::DataAccessor Resource Type
 */
export declare class DataAccessor extends pulumi.CustomResource {
    /**
     * Get an existing DataAccessor resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataAccessor;
    /**
     * Returns true if the given object is an instance of DataAccessor.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataAccessor;
    /**
     * A list of action configurations specifying the allowed actions and any associated filters.
     */
    readonly actionConfigurations: pulumi.Output<outputs.qbusiness.DataAccessorActionConfiguration[]>;
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The authentication configuration details for the data accessor. This specifies how the ISV authenticates when accessing data through this data accessor.
     */
    readonly authenticationDetail: pulumi.Output<outputs.qbusiness.DataAccessorAuthenticationDetail | undefined>;
    /**
     * The timestamp when the data accessor was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the data accessor.
     */
    readonly dataAccessorArn: pulumi.Output<string>;
    /**
     * The unique identifier of the data accessor.
     */
    readonly dataAccessorId: pulumi.Output<string>;
    /**
     * The friendly name of the data accessor.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the associated IAM Identity Center application.
     */
    readonly idcApplicationArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role for the ISV associated with this data accessor.
     */
    readonly principal: pulumi.Output<string>;
    /**
     * The tags to associate with the data accessor.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The timestamp when the data accessor was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a DataAccessor resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DataAccessorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataAccessor resource.
 */
export interface DataAccessorArgs {
    /**
     * A list of action configurations specifying the allowed actions and any associated filters.
     */
    actionConfigurations: pulumi.Input<pulumi.Input<inputs.qbusiness.DataAccessorActionConfigurationArgs>[]>;
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The authentication configuration details for the data accessor. This specifies how the ISV authenticates when accessing data through this data accessor.
     */
    authenticationDetail?: pulumi.Input<inputs.qbusiness.DataAccessorAuthenticationDetailArgs>;
    /**
     * The friendly name of the data accessor.
     */
    displayName: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role for the ISV associated with this data accessor.
     */
    principal: pulumi.Input<string>;
    /**
     * The tags to associate with the data accessor.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
