import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::QBusiness::Permission Resource Type
 */
export declare class Permission extends pulumi.CustomResource {
    /**
     * Get an existing Permission resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Permission;
    /**
     * Returns true if the given object is an instance of Permission.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Permission;
    /**
     * The list of Amazon Q Business actions that the ISV is allowed to perform.
     */
    readonly actions: pulumi.Output<string[]>;
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    readonly applicationId: pulumi.Output<string>;
    readonly conditions: pulumi.Output<outputs.qbusiness.PermissionCondition[] | undefined>;
    /**
     * Provides user and group information used for filtering documents to use for generating Amazon Q Business conversation responses.
     */
    readonly principal: pulumi.Output<string>;
    /**
     * A unique identifier for the policy statement.
     */
    readonly statementId: pulumi.Output<string>;
    /**
     * Create a Permission resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PermissionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Permission resource.
 */
export interface PermissionArgs {
    /**
     * The list of Amazon Q Business actions that the ISV is allowed to perform.
     */
    actions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The unique identifier of the Amazon Q Business application.
     */
    applicationId: pulumi.Input<string>;
    conditions?: pulumi.Input<pulumi.Input<inputs.qbusiness.PermissionConditionArgs>[]>;
    /**
     * Provides user and group information used for filtering documents to use for generating Amazon Q Business conversation responses.
     */
    principal: pulumi.Input<string>;
    /**
     * A unique identifier for the policy statement.
     */
    statementId: pulumi.Input<string>;
}
