import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::RAM::ResourceShare
 */
export declare function getResourceShare(args: GetResourceShareArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceShareResult>;
export interface GetResourceShareArgs {
    /**
     * The Amazon Resource Name (ARN) of the resource share.
     */
    arn: string;
}
export interface GetResourceShareResult {
    /**
     * Specifies whether principals outside your organization in AWS Organizations can be associated with a resource share. A value of `true` lets you share with individual AWS accounts that are not in your organization. A value of `false` only has meaning if your account is a member of an AWS Organization. The default value is `true`.
     */
    readonly allowExternalPrincipals?: boolean;
    /**
     * The Amazon Resource Name (ARN) of the resource share.
     */
    readonly arn?: string;
    /**
     * Specifies the name of the resource share.
     */
    readonly name?: string;
    /**
     * Specifies one or more tags to attach to the resource share itself. It doesn't attach the tags to the resources associated with the resource share.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource type definition for AWS::RAM::ResourceShare
 */
export declare function getResourceShareOutput(args: GetResourceShareOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResourceShareResult>;
export interface GetResourceShareOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the resource share.
     */
    arn: pulumi.Input<string>;
}
