import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::RDS::OptionGroup`` resource creates or updates an option group, to enable and configure features that are specific to a particular DB engine.
 */
export declare function getOptionGroup(args: GetOptionGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetOptionGroupResult>;
export interface GetOptionGroupArgs {
    /**
     * The name of the option group to be created.
     *  Constraints:
     *   +  Must be 1 to 255 letters, numbers, or hyphens
     *   +  First character must be a letter
     *   +  Can't end with a hyphen or contain two consecutive hyphens
     *
     *  Example: ``myoptiongroup``
     *  If you don't specify a value for ``OptionGroupName`` property, a name is automatically created for the option group.
     *   This value is stored as a lowercase string.
     */
    optionGroupName: string;
}
export interface GetOptionGroupResult {
    /**
     * A list of all available options for an option group.
     */
    readonly optionConfigurations?: outputs.rds.OptionGroupOptionConfiguration[];
    /**
     * Tags to assign to the option group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The ``AWS::RDS::OptionGroup`` resource creates or updates an option group, to enable and configure features that are specific to a particular DB engine.
 */
export declare function getOptionGroupOutput(args: GetOptionGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOptionGroupResult>;
export interface GetOptionGroupOutputArgs {
    /**
     * The name of the option group to be created.
     *  Constraints:
     *   +  Must be 1 to 255 letters, numbers, or hyphens
     *   +  First character must be a letter
     *   +  Can't end with a hyphen or contain two consecutive hyphens
     *
     *  Example: ``myoptiongroup``
     *  If you don't specify a value for ``OptionGroupName`` property, a name is automatically created for the option group.
     *   This value is stored as a lowercase string.
     */
    optionGroupName: pulumi.Input<string>;
}
