import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * AWS Route53 Recovery Control Control Panel resource schema .
 */
export declare class ControlPanel extends pulumi.CustomResource {
    /**
     * Get an existing ControlPanel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ControlPanel;
    /**
     * Returns true if the given object is an instance of ControlPanel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ControlPanel;
    /**
     * Cluster to associate with the Control Panel
     */
    readonly clusterArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the cluster.
     */
    readonly controlPanelArn: pulumi.Output<string>;
    /**
     * A flag that Amazon Route 53 Application Recovery Controller sets to true to designate the default control panel for a cluster. When you create a cluster, Amazon Route 53 Application Recovery Controller creates a control panel, and sets this flag for that control panel. If you create a control panel yourself, this flag is set to false.
     */
    readonly defaultControlPanel: pulumi.Output<boolean>;
    /**
     * The name of the control panel. You can use any non-white space character in the name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Count of associated routing controls
     */
    readonly routingControlCount: pulumi.Output<number>;
    /**
     * The deployment status of control panel. Status can be one of the following: PENDING, DEPLOYED, PENDING_DELETION.
     */
    readonly status: pulumi.Output<enums.route53recoverycontrol.ControlPanelStatus>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a ControlPanel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ControlPanelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ControlPanel resource.
 */
export interface ControlPanelArgs {
    /**
     * Cluster to associate with the Control Panel
     */
    clusterArn?: pulumi.Input<string>;
    /**
     * The name of the control panel. You can use any non-white space character in the name.
     */
    name?: pulumi.Input<string>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
