import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The API Schema for AWS Route53 Recovery Readiness Cells.
 */
export declare function getCell(args: GetCellArgs, opts?: pulumi.InvokeOptions): Promise<GetCellResult>;
export interface GetCellArgs {
    /**
     * The name of the cell to create.
     */
    cellName: string;
}
export interface GetCellResult {
    /**
     * The Amazon Resource Name (ARN) of the cell.
     */
    readonly cellArn?: string;
    /**
     * A list of cell Amazon Resource Names (ARNs) contained within this cell, for use in nested cells. For example, Availability Zones within specific Regions.
     */
    readonly cells?: string[];
    /**
     * The readiness scope for the cell, which can be a cell Amazon Resource Name (ARN) or a recovery group ARN. This is a list but currently can have only one element.
     */
    readonly parentReadinessScopes?: string[];
    /**
     * A collection of tags associated with a resource
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The API Schema for AWS Route53 Recovery Readiness Cells.
 */
export declare function getCellOutput(args: GetCellOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCellResult>;
export interface GetCellOutputArgs {
    /**
     * The name of the cell to create.
     */
    cellName: pulumi.Input<string>;
}
