import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::ModelBiasJobDefinition
 */
export declare class ModelBiasJobDefinition extends pulumi.CustomResource {
    /**
     * Get an existing ModelBiasJobDefinition resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ModelBiasJobDefinition;
    /**
     * Returns true if the given object is an instance of ModelBiasJobDefinition.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ModelBiasJobDefinition;
    /**
     * The time at which the job definition was created.
     */
    readonly creationTime: pulumi.Output<string>;
    readonly endpointName: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of job definition.
     */
    readonly jobDefinitionArn: pulumi.Output<string>;
    /**
     * The name of the bias job definition. The name must be unique within an AWS Region in the AWS account.
     */
    readonly jobDefinitionName: pulumi.Output<string | undefined>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    readonly jobResources: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionMonitoringResources>;
    /**
     * Configures the model bias job to run a specified Docker container image.
     */
    readonly modelBiasAppSpecification: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionModelBiasAppSpecification>;
    /**
     * The baseline configuration for a model bias job.
     */
    readonly modelBiasBaselineConfig: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionModelBiasBaselineConfig | undefined>;
    /**
     * Inputs for the model bias job.
     */
    readonly modelBiasJobInput: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionModelBiasJobInput>;
    /**
     * The output configuration for monitoring jobs.
     */
    readonly modelBiasJobOutputConfig: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionMonitoringOutputConfig>;
    /**
     * Networking options for a model bias job.
     */
    readonly networkConfig: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionNetworkConfig | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    readonly stoppingCondition: pulumi.Output<outputs.sagemaker.ModelBiasJobDefinitionStoppingCondition | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a ModelBiasJobDefinition resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelBiasJobDefinitionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ModelBiasJobDefinition resource.
 */
export interface ModelBiasJobDefinitionArgs {
    endpointName?: pulumi.Input<string>;
    /**
     * The name of the bias job definition. The name must be unique within an AWS Region in the AWS account.
     */
    jobDefinitionName?: pulumi.Input<string>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    jobResources: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionMonitoringResourcesArgs>;
    /**
     * Configures the model bias job to run a specified Docker container image.
     */
    modelBiasAppSpecification: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionModelBiasAppSpecificationArgs>;
    /**
     * The baseline configuration for a model bias job.
     */
    modelBiasBaselineConfig?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionModelBiasBaselineConfigArgs>;
    /**
     * Inputs for the model bias job.
     */
    modelBiasJobInput: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionModelBiasJobInputArgs>;
    /**
     * The output configuration for monitoring jobs.
     */
    modelBiasJobOutputConfig: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionMonitoringOutputConfigArgs>;
    /**
     * Networking options for a model bias job.
     */
    networkConfig?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionNetworkConfigArgs>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    stoppingCondition?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionStoppingConditionArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
