import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::ModelCard.
 */
export declare class ModelCard extends pulumi.CustomResource {
    /**
     * Get an existing ModelCard resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ModelCard;
    /**
     * Returns true if the given object is an instance of ModelCard.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ModelCard;
    /**
     * The content of the model card. Content uses the [model card JSON schema](https://docs.aws.amazon.com/sagemaker/latest/dg/model-cards.html#model-cards-json-schema) .
     */
    readonly content: pulumi.Output<outputs.sagemaker.ModelCardContent>;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    readonly createdBy: pulumi.Output<outputs.sagemaker.ModelCardUserContext | undefined>;
    /**
     * The date and time the model card was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    readonly lastModifiedBy: pulumi.Output<outputs.sagemaker.ModelCardUserContext | undefined>;
    /**
     * The date and time the model card was last modified.
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the successfully created model card.
     */
    readonly modelCardArn: pulumi.Output<string>;
    /**
     * The unique name of the model card.
     */
    readonly modelCardName: pulumi.Output<string>;
    /**
     * The processing status of model card deletion. The ModelCardProcessingStatus updates throughout the different deletion steps.
     */
    readonly modelCardProcessingStatus: pulumi.Output<enums.sagemaker.ModelCardProcessingStatus>;
    /**
     * The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
     */
    readonly modelCardStatus: pulumi.Output<enums.sagemaker.ModelCardStatus>;
    /**
     * A version of the model card.
     */
    readonly modelCardVersion: pulumi.Output<number>;
    /**
     * The security configuration used to protect model card data.
     */
    readonly securityConfig: pulumi.Output<outputs.sagemaker.ModelCardSecurityConfig | undefined>;
    /**
     * Key-value pairs used to manage metadata for model cards.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ModelCard resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelCardArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ModelCard resource.
 */
export interface ModelCardArgs {
    /**
     * The content of the model card. Content uses the [model card JSON schema](https://docs.aws.amazon.com/sagemaker/latest/dg/model-cards.html#model-cards-json-schema) .
     */
    content: pulumi.Input<inputs.sagemaker.ModelCardContentArgs>;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    createdBy?: pulumi.Input<inputs.sagemaker.ModelCardUserContextArgs>;
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    lastModifiedBy?: pulumi.Input<inputs.sagemaker.ModelCardUserContextArgs>;
    /**
     * The unique name of the model card.
     */
    modelCardName?: pulumi.Input<string>;
    /**
     * The approval status of the model card within your organization. Different organizations might have different criteria for model card review and approval.
     */
    modelCardStatus: pulumi.Input<enums.sagemaker.ModelCardStatus>;
    /**
     * The security configuration used to protect model card data.
     */
    securityConfig?: pulumi.Input<inputs.sagemaker.ModelCardSecurityConfigArgs>;
    /**
     * Key-value pairs used to manage metadata for model cards.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
