import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * The AWS::SecurityHub::AggregatorV2 resource represents the AWS Security Hub AggregatorV2 in your account. One aggregatorv2 resource is created for each account in non opt-in region in which you configure region linking mode.
 */
export declare function getAggregatorV2(args: GetAggregatorV2Args, opts?: pulumi.InvokeOptions): Promise<GetAggregatorV2Result>;
export interface GetAggregatorV2Args {
    /**
     * The ARN of the AggregatorV2 being created and assigned as the unique identifier
     */
    aggregatorV2Arn: string;
}
export interface GetAggregatorV2Result {
    /**
     * The aggregation Region of the AggregatorV2
     */
    readonly aggregationRegion?: string;
    /**
     * The ARN of the AggregatorV2 being created and assigned as the unique identifier
     */
    readonly aggregatorV2Arn?: string;
    /**
     * The list of included Regions
     */
    readonly linkedRegions?: string[];
    /**
     * Indicates to link a list of included Regions
     */
    readonly regionLinkingMode?: enums.securityhub.AggregatorV2RegionLinkingMode;
    /**
     * A list of key-value pairs to be applied to the AggregatorV2.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * The AWS::SecurityHub::AggregatorV2 resource represents the AWS Security Hub AggregatorV2 in your account. One aggregatorv2 resource is created for each account in non opt-in region in which you configure region linking mode.
 */
export declare function getAggregatorV2Output(args: GetAggregatorV2OutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAggregatorV2Result>;
export interface GetAggregatorV2OutputArgs {
    /**
     * The ARN of the AggregatorV2 being created and assigned as the unique identifier
     */
    aggregatorV2Arn: pulumi.Input<string>;
}
