import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::SecurityHub::HubV2 resource represents the implementation of the AWS Security Hub V2 service in your account. Only one hubv2 resource can created in each region in which you enable Security Hub V2.
 */
export declare class HubV2 extends pulumi.CustomResource {
    /**
     * Get an existing HubV2 resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): HubV2;
    /**
     * Returns true if the given object is an instance of HubV2.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HubV2;
    /**
     * The Amazon Resource Name of the Security Hub V2 resource.
     */
    readonly hubV2Arn: pulumi.Output<string>;
    /**
     * The date and time when the service was enabled in the account.
     */
    readonly subscribedAt: pulumi.Output<string>;
    /**
     * The tags to add to the hub V2 resource when you enable Security Hub.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a HubV2 resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: HubV2Args, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a HubV2 resource.
 */
export interface HubV2Args {
    /**
     * The tags to add to the hub V2 resource when you enable Security Hub.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
