import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Schema for AWS::ServiceCatalogAppRegistry::Application
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
export interface GetApplicationArgs {
    /**
     * The identifier of the application.
     */
    id: string;
}
export interface GetApplicationResult {
    /**
     * The name of the application.
     */
    readonly applicationName?: string;
    /**
     * The key of the AWS application tag, which is awsApplication. Applications created before 11/13/2023 or applications without the AWS application tag resource group return no value.
     */
    readonly applicationTagKey?: string;
    /**
     * The value of the AWS application tag, which is the identifier of an associated resource. Applications created before 11/13/2023 or applications without the AWS application tag resource group return no value.
     */
    readonly applicationTagValue?: string;
    /**
     * The Amazon resource name (ARN) that specifies the application across services.
     */
    readonly arn?: string;
    /**
     * The description of the application.
     */
    readonly description?: string;
    /**
     * The identifier of the application.
     */
    readonly id?: string;
    /**
     * The name of the application.
     */
    readonly name?: string;
    /**
     * Key-value pairs you can use to associate with the application.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Resource Schema for AWS::ServiceCatalogAppRegistry::Application
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
export interface GetApplicationOutputArgs {
    /**
     * The identifier of the application.
     */
    id: pulumi.Input<string>;
}
