import * as pulumi from "@pulumi/pulumi";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare class ProfilePermission extends pulumi.CustomResource {
    /**
     * Get an existing ProfilePermission resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProfilePermission;
    /**
     * Returns true if the given object is an instance of ProfilePermission.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProfilePermission;
    /**
     * The AWS Signer action permitted as part of cross-account permissions.
     */
    readonly action: pulumi.Output<string>;
    /**
     * The AWS principal receiving cross-account permissions. This may be an IAM role or another AWS account ID.
     */
    readonly principal: pulumi.Output<string>;
    /**
     * The human-readable name of the signing profile.
     */
    readonly profileName: pulumi.Output<string>;
    /**
     * The version of the signing profile.
     */
    readonly profileVersion: pulumi.Output<string | undefined>;
    /**
     * A unique identifier for the cross-account permission statement.
     */
    readonly statementId: pulumi.Output<string>;
    /**
     * Create a ProfilePermission resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProfilePermissionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProfilePermission resource.
 */
export interface ProfilePermissionArgs {
    /**
     * The AWS Signer action permitted as part of cross-account permissions.
     */
    action: pulumi.Input<string>;
    /**
     * The AWS principal receiving cross-account permissions. This may be an IAM role or another AWS account ID.
     */
    principal: pulumi.Input<string>;
    /**
     * The human-readable name of the signing profile.
     */
    profileName: pulumi.Input<string>;
    /**
     * The version of the signing profile.
     */
    profileVersion?: pulumi.Input<string>;
    /**
     * A unique identifier for the cross-account permission statement.
     */
    statementId: pulumi.Input<string>;
}
