import * as pulumi from "@pulumi/pulumi";
/**
 * Schema for AWS::SNS::TopicInlinePolicy
 */
export declare class TopicInlinePolicy extends pulumi.CustomResource {
    /**
     * Get an existing TopicInlinePolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TopicInlinePolicy;
    /**
     * Returns true if the given object is an instance of TopicInlinePolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TopicInlinePolicy;
    /**
     * A policy document that contains permissions to add to the specified SNS topics.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::TopicInlinePolicy` for more information about the expected schema for this property.
     */
    readonly policyDocument: pulumi.Output<any>;
    /**
     * The Amazon Resource Name (ARN) of the topic to which you want to add the policy.
     */
    readonly topicArn: pulumi.Output<string>;
    /**
     * Create a TopicInlinePolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TopicInlinePolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TopicInlinePolicy resource.
 */
export interface TopicInlinePolicyArgs {
    /**
     * A policy document that contains permissions to add to the specified SNS topics.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::TopicInlinePolicy` for more information about the expected schema for this property.
     */
    policyDocument: any;
    /**
     * The Amazon Resource Name (ARN) of the topic to which you want to add the policy.
     */
    topicArn: pulumi.Input<string>;
}
