export declare const ConfigurationProfileDeletionProtectionCheck: {
    readonly AccountDefault: "ACCOUNT_DEFAULT";
    readonly Apply: "APPLY";
    readonly Bypass: "BYPASS";
};
/**
 * On resource deletion this controls whether the Deletion Protection check should be applied, bypassed, or (the default) whether the behavior should be controlled by the account-level Deletion Protection setting. See https://docs.aws.amazon.com/appconfig/latest/userguide/deletion-protection.html
 */
export type ConfigurationProfileDeletionProtectionCheck = (typeof ConfigurationProfileDeletionProtectionCheck)[keyof typeof ConfigurationProfileDeletionProtectionCheck];
export declare const DeploymentStrategyGrowthType: {
    readonly Exponential: "EXPONENTIAL";
    readonly Linear: "LINEAR";
};
/**
 * The algorithm used to define how percentage grows over time. AWS AppConfig supports the following growth types:
 *
 * Linear: For this type, AWS AppConfig processes the deployment by dividing the total number of targets by the value specified for Step percentage. For example, a linear deployment that uses a Step percentage of 10 deploys the configuration to 10 percent of the hosts. After those deployments are complete, the system deploys the configuration to the next 10 percent. This continues until 100% of the targets have successfully received the configuration.
 *
 * Exponential: For this type, AWS AppConfig processes the deployment exponentially using the following formula: G*(2^N). In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:
 *
 * 2*(2^0)
 *
 * 2*(2^1)
 *
 * 2*(2^2)
 *
 * Expressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets.
 */
export type DeploymentStrategyGrowthType = (typeof DeploymentStrategyGrowthType)[keyof typeof DeploymentStrategyGrowthType];
export declare const DeploymentStrategyReplicateTo: {
    readonly None: "NONE";
    readonly SsmDocument: "SSM_DOCUMENT";
};
/**
 * Save the deployment strategy to a Systems Manager (SSM) document.
 */
export type DeploymentStrategyReplicateTo = (typeof DeploymentStrategyReplicateTo)[keyof typeof DeploymentStrategyReplicateTo];
export declare const EnvironmentDeletionProtectionCheck: {
    readonly AccountDefault: "ACCOUNT_DEFAULT";
    readonly Apply: "APPLY";
    readonly Bypass: "BYPASS";
};
/**
 * On resource deletion this controls whether the Deletion Protection check should be applied, bypassed, or (the default) whether the behavior should be controlled by the account-level Deletion Protection setting. See https://docs.aws.amazon.com/appconfig/latest/userguide/deletion-protection.html
 */
export type EnvironmentDeletionProtectionCheck = (typeof EnvironmentDeletionProtectionCheck)[keyof typeof EnvironmentDeletionProtectionCheck];
