import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A service is any software application that can run on instances containers, or serverless functions within an account or virtual private cloud (VPC).
 */
export declare function getService(args: GetServiceArgs, opts?: pulumi.InvokeOptions): Promise<GetServiceResult>;
export interface GetServiceArgs {
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    arn: string;
}
export interface GetServiceResult {
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    readonly arn?: string;
    /**
     * The type of IAM policy.
     *
     * - `NONE` : The resource does not use an IAM policy. This is the default.
     * - `AWS_IAM` : The resource uses an IAM policy. When this type is used, auth is enabled and an auth policy is required.
     */
    readonly authType?: enums.vpclattice.ServiceAuthType;
    /**
     * The Amazon Resource Name (ARN) of the certificate.
     */
    readonly certificateArn?: string;
    /**
     * The date and time that the service was created, specified in ISO-8601 format.
     */
    readonly createdAt?: string;
    /**
     * Describes the DNS information of the service. This field is read-only.
     */
    readonly dnsEntry?: outputs.vpclattice.ServiceDnsEntry;
    /**
     * The ID of the service.
     */
    readonly id?: string;
    /**
     * The date and time that the service was last updated, specified in ISO-8601 format.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The status of the service.
     */
    readonly status?: enums.vpclattice.ServiceStatus;
    /**
     * The tags for the service.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A service is any software application that can run on instances containers, or serverless functions within an account or virtual private cloud (VPC).
 */
export declare function getServiceOutput(args: GetServiceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetServiceResult>;
export interface GetServiceOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    arn: pulumi.Input<string>;
}
