import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A target group is a collection of targets, or compute resources, that run your application or service. A target group can only be used by a single service.
 */
export declare class TargetGroup extends pulumi.CustomResource {
    /**
     * Get an existing TargetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TargetGroup;
    /**
     * Returns true if the given object is an instance of TargetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TargetGroup;
    /**
     * The Amazon Resource Name (ARN) of the target group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the target group.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The target group configuration.
     */
    readonly config: pulumi.Output<outputs.vpclattice.TargetGroupConfig | undefined>;
    /**
     * The date and time that the target group was created, specified in ISO-8601 format.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The date and time that the target group was last updated, specified in ISO-8601 format.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The name of the target group. The name must be unique within the account. The valid characters are a-z, 0-9, and hyphens (-). You can't use a hyphen as the first or last character, or immediately after another hyphen.
     *
     * If you don't specify a name, CloudFormation generates one. However, if you specify a name, and later want to replace the resource, you must specify a new name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The operation's status. You can retry the operation if the status is `CREATE_FAILED` . However, if you retry it while the status is `CREATE_IN_PROGRESS` , there is no change in the status.
     */
    readonly status: pulumi.Output<enums.vpclattice.TargetGroupStatus>;
    /**
     * The tags for the target group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Describes a target.
     */
    readonly targets: pulumi.Output<outputs.vpclattice.TargetGroupTarget[] | undefined>;
    /**
     * The type of target group.
     */
    readonly type: pulumi.Output<enums.vpclattice.TargetGroupType>;
    /**
     * Create a TargetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TargetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TargetGroup resource.
 */
export interface TargetGroupArgs {
    /**
     * The target group configuration.
     */
    config?: pulumi.Input<inputs.vpclattice.TargetGroupConfigArgs>;
    /**
     * The name of the target group. The name must be unique within the account. The valid characters are a-z, 0-9, and hyphens (-). You can't use a hyphen as the first or last character, or immediately after another hyphen.
     *
     * If you don't specify a name, CloudFormation generates one. However, if you specify a name, and later want to replace the resource, you must specify a new name.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags for the target group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Describes a target.
     */
    targets?: pulumi.Input<pulumi.Input<inputs.vpclattice.TargetGroupTargetArgs>[]>;
    /**
     * The type of target group.
     */
    type: pulumi.Input<enums.vpclattice.TargetGroupType>;
}
