import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::Wisdom::AIAgentVersion Resource Type
 */
export declare class AiAgentVersion extends pulumi.CustomResource {
    /**
     * Get an existing AiAgentVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AiAgentVersion;
    /**
     * Returns true if the given object is an instance of AiAgentVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AiAgentVersion;
    readonly aiAgentArn: pulumi.Output<string>;
    /**
     * The identifier of the AI Agent.
     */
    readonly aiAgentId: pulumi.Output<string>;
    readonly aiAgentVersionId: pulumi.Output<string>;
    readonly assistantArn: pulumi.Output<string>;
    readonly assistantId: pulumi.Output<string>;
    /**
     * The time the AI Agent version was last modified in seconds.
     */
    readonly modifiedTimeSeconds: pulumi.Output<number | undefined>;
    /**
     * The version number for this AI Agent version.
     */
    readonly versionNumber: pulumi.Output<number>;
    /**
     * Create a AiAgentVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AiAgentVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AiAgentVersion resource.
 */
export interface AiAgentVersionArgs {
    /**
     * The identifier of the AI Agent.
     */
    aiAgentId: pulumi.Input<string>;
    assistantId: pulumi.Input<string>;
    /**
     * The time the AI Agent version was last modified in seconds.
     */
    modifiedTimeSeconds?: pulumi.Input<number>;
}
