import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Wisdom::MessageTemplate Resource Type
 */
export declare class MessageTemplate extends pulumi.CustomResource {
    /**
     * Get an existing MessageTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MessageTemplate;
    /**
     * Returns true if the given object is an instance of MessageTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MessageTemplate;
    /**
     * The channel subtype this message template applies to.
     */
    readonly channelSubtype: pulumi.Output<enums.wisdom.MessageTemplateChannelSubtype>;
    /**
     * The content of the message template.
     */
    readonly content: pulumi.Output<outputs.wisdom.MessageTemplateContent>;
    /**
     * An object that specifies the default values to use for variables in the message template. This object contains different categories of key-value pairs. Each key defines a variable or placeholder in the message template. The corresponding value defines the default value for that variable.
     */
    readonly defaultAttributes: pulumi.Output<outputs.wisdom.MessageTemplateAttributes | undefined>;
    /**
     * The description of the message template.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The configuration information of the external data source.
     */
    readonly groupingConfiguration: pulumi.Output<outputs.wisdom.MessageTemplateGroupingConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the knowledge base to which the message template belongs.
     */
    readonly knowledgeBaseArn: pulumi.Output<string>;
    /**
     * The language code value for the language in which the message template is written. The supported language codes include de_DE, en_US, es_ES, fr_FR, id_ID, it_IT, ja_JP, ko_KR, pt_BR, zh_CN, zh_TW
     */
    readonly language: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the message template.
     */
    readonly messageTemplateArn: pulumi.Output<string>;
    /**
     * The content SHA256 of the message template.
     */
    readonly messageTemplateContentSha256: pulumi.Output<string>;
    /**
     * The unique identifier of the message template.
     */
    readonly messageTemplateId: pulumi.Output<string>;
    /**
     * The name of the message template.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MessageTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MessageTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MessageTemplate resource.
 */
export interface MessageTemplateArgs {
    /**
     * The channel subtype this message template applies to.
     */
    channelSubtype: pulumi.Input<enums.wisdom.MessageTemplateChannelSubtype>;
    /**
     * The content of the message template.
     */
    content: pulumi.Input<inputs.wisdom.MessageTemplateContentArgs>;
    /**
     * An object that specifies the default values to use for variables in the message template. This object contains different categories of key-value pairs. Each key defines a variable or placeholder in the message template. The corresponding value defines the default value for that variable.
     */
    defaultAttributes?: pulumi.Input<inputs.wisdom.MessageTemplateAttributesArgs>;
    /**
     * The description of the message template.
     */
    description?: pulumi.Input<string>;
    /**
     * The configuration information of the external data source.
     */
    groupingConfiguration?: pulumi.Input<inputs.wisdom.MessageTemplateGroupingConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) of the knowledge base to which the message template belongs.
     */
    knowledgeBaseArn: pulumi.Input<string>;
    /**
     * The language code value for the language in which the message template is written. The supported language codes include de_DE, en_US, es_ES, fr_FR, id_ID, it_IT, ja_JP, ko_KR, pt_BR, zh_CN, zh_TW
     */
    language?: pulumi.Input<string>;
    /**
     * The name of the message template.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
