import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::WorkspacesInstances::Volume - Manages WorkSpaces Volume resources
 */
export declare class Volume extends pulumi.CustomResource {
    /**
     * Get an existing Volume resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Volume;
    /**
     * Returns true if the given object is an instance of Volume.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Volume;
    /**
     * The Availability Zone in which to create the volume
     */
    readonly availabilityZone: pulumi.Output<string>;
    /**
     * Indicates whether the volume should be encrypted
     */
    readonly encrypted: pulumi.Output<boolean | undefined>;
    /**
     * The number of I/O operations per second (IOPS)
     */
    readonly iops: pulumi.Output<number | undefined>;
    /**
     * The identifier of the AWS Key Management Service (AWS KMS) customer master key (CMK) to use for Amazon EBS encryption
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * The size of the volume, in GiBs
     */
    readonly sizeInGb: pulumi.Output<number | undefined>;
    /**
     * The snapshot from which to create the volume
     */
    readonly snapshotId: pulumi.Output<string | undefined>;
    /**
     * The tags passed to EBS volume
     */
    readonly tagSpecifications: pulumi.Output<outputs.workspacesinstances.VolumeTagSpecification[] | undefined>;
    /**
     * The throughput to provision for a volume, with a maximum of 1,000 MiB/s
     */
    readonly throughput: pulumi.Output<number | undefined>;
    /**
     * Unique identifier for the volume
     */
    readonly volumeId: pulumi.Output<string>;
    /**
     * The volume type
     */
    readonly volumeType: pulumi.Output<enums.workspacesinstances.VolumeType | undefined>;
    /**
     * Create a Volume resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VolumeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Volume resource.
 */
export interface VolumeArgs {
    /**
     * The Availability Zone in which to create the volume
     */
    availabilityZone: pulumi.Input<string>;
    /**
     * Indicates whether the volume should be encrypted
     */
    encrypted?: pulumi.Input<boolean>;
    /**
     * The number of I/O operations per second (IOPS)
     */
    iops?: pulumi.Input<number>;
    /**
     * The identifier of the AWS Key Management Service (AWS KMS) customer master key (CMK) to use for Amazon EBS encryption
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * The size of the volume, in GiBs
     */
    sizeInGb?: pulumi.Input<number>;
    /**
     * The snapshot from which to create the volume
     */
    snapshotId?: pulumi.Input<string>;
    /**
     * The tags passed to EBS volume
     */
    tagSpecifications?: pulumi.Input<pulumi.Input<inputs.workspacesinstances.VolumeTagSpecificationArgs>[]>;
    /**
     * The throughput to provision for a volume, with a maximum of 1,000 MiB/s
     */
    throughput?: pulumi.Input<number>;
    /**
     * The volume type
     */
    volumeType?: pulumi.Input<enums.workspacesinstances.VolumeType>;
}
