import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::WorkspacesInstances::WorkspaceInstance
 */
export declare class WorkspaceInstance extends pulumi.CustomResource {
    /**
     * Get an existing WorkspaceInstance resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WorkspaceInstance;
    /**
     * Returns true if the given object is an instance of WorkspaceInstance.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WorkspaceInstance;
    readonly ec2ManagedInstance: pulumi.Output<outputs.workspacesinstances.WorkspaceInstanceEc2ManagedInstance>;
    readonly managedInstance: pulumi.Output<outputs.workspacesinstances.ManagedInstanceProperties | undefined>;
    /**
     * The current state of the workspace instance
     */
    readonly provisionState: pulumi.Output<enums.workspacesinstances.WorkspaceInstanceProvisionState>;
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Unique identifier for the workspace instance
     */
    readonly workspaceInstanceId: pulumi.Output<string>;
    /**
     * Create a WorkspaceInstance resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: WorkspaceInstanceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WorkspaceInstance resource.
 */
export interface WorkspaceInstanceArgs {
    managedInstance?: pulumi.Input<inputs.workspacesinstances.ManagedInstancePropertiesArgs>;
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
