import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::WorkSpacesWeb::IdentityProvider Resource Type
 */
export declare function getIdentityProvider(args: GetIdentityProviderArgs, opts?: pulumi.InvokeOptions): Promise<GetIdentityProviderResult>;
export interface GetIdentityProviderArgs {
    /**
     * The ARN of the identity provider.
     */
    identityProviderArn: string;
}
export interface GetIdentityProviderResult {
    /**
     * The ARN of the identity provider.
     */
    readonly identityProviderArn?: string;
    /**
     * The identity provider details. The following list describes the provider detail keys for each identity provider type.
     *
     * - For Google and Login with Amazon:
     *
     * - `client_id`
     * - `client_secret`
     * - `authorize_scopes`
     * - For Facebook:
     *
     * - `client_id`
     * - `client_secret`
     * - `authorize_scopes`
     * - `api_version`
     * - For Sign in with Apple:
     *
     * - `client_id`
     * - `team_id`
     * - `key_id`
     * - `private_key`
     * - `authorize_scopes`
     * - For OIDC providers:
     *
     * - `client_id`
     * - `client_secret`
     * - `attributes_request_method`
     * - `oidc_issuer`
     * - `authorize_scopes`
     * - `authorize_url` *if not available from discovery URL specified by oidc_issuer key*
     * - `token_url` *if not available from discovery URL specified by oidc_issuer key*
     * - `attributes_url` *if not available from discovery URL specified by oidc_issuer key*
     * - `jwks_uri` *if not available from discovery URL specified by oidc_issuer key*
     * - For SAML providers:
     *
     * - `MetadataFile` OR `MetadataURL`
     * - `IDPSignout` (boolean) *optional*
     * - `IDPInit` (boolean) *optional*
     * - `RequestSigningAlgorithm` (string) *optional* - Only accepts `rsa-sha256`
     * - `EncryptedResponses` (boolean) *optional*
     */
    readonly identityProviderDetails?: {
        [key: string]: string;
    };
    /**
     * The identity provider name.
     */
    readonly identityProviderName?: string;
    /**
     * The identity provider type.
     */
    readonly identityProviderType?: enums.workspacesweb.IdentityProviderType;
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::WorkSpacesWeb::IdentityProvider Resource Type
 */
export declare function getIdentityProviderOutput(args: GetIdentityProviderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIdentityProviderResult>;
export interface GetIdentityProviderOutputArgs {
    /**
     * The ARN of the identity provider.
     */
    identityProviderArn: pulumi.Input<string>;
}
